% Chap2 - Chapter 2 textbook help for DELab
%
%           Differential Equations: Modeling with Matlab
%                  Paul Davis, Prentice Hall 1999
%
% >> Figure 2.2
%
%    Follow the directions under chapter 1, figure 1.2 but select
%    Equation/From list/Simple population from the First-order
%    equation window menu bar.  Select Graphical tools/Direction
%    field from the First-order equation menu bar.  As desired,
%    edit the min P and max P values to adjust the range of
%    population values displayed.  Click Plot to display the
%    direction field.
%
%    To select initial values by clicking on the direction field,
%    select the Initial value-Click on figure radio button in the
%    Direction field window, then position the cursor over the
%    direction field figure and click on the desired point.
%
% >> Example 2
%
%    From the First-order equation window, select Equation/From
%    list/Simple population.  Delete the value of the parameter k;
%    e.g., double click the entered value of 0.0102 and touch the
%    delete key.  Similarly, edit "P(1970) = 205.05" to "P(t0) =
%    Pi".  On Windows systems, remember to touch the ENTER key
%    after each edit.
%
%    From the menu bar, choose Analytic tools/IVP solution.  Is the
%    solution formula in the resulting Analytic solution window the
%    one you expected.  If not, choose Manipulate/Simple or
%    Manipulate/Simplify from the Analytic solution menu bar.  Does
%    either choice produce a solution formula more to your liking?
%    (Note that Matlab insists on converting "Pi" or "P_i" to
%    "pi".)
%
%    MORE: To verify the correctness of the solution formula in the
%    Analytic solution window, choose Manipulate/Use in Matlab
%    as/Symbolic expression.  A message will appear telling you
%    that the expression is available in Matlab as P_2, say.  Click
%    OK in the message box, then click the Matlab command window to
%    begin testing that the differential equation and initial
%    condition are satisfied.
%
%    To substitute P_2 in the differential equation, type
%
%        diff( P_2, t ) - k*P_2
%
%    to represent d P_2/dt - k P_2.  Is the answer what you
%    expected? To test the initial condition, type
%
%        subs( P_2, t, t0 )
%
%    to substitute t = t0 into the function P_2.  Is the initial
%    condition satisfied by P_2?
%
%    For more information about these Matlab functions, type help
%    diff or help sym/subs.
%
% >> Example 4
%
%    From the First-order equation window, select Equation/From
%    list/Simple population.  As in example 2, delete the value of
%    the parameter k, and edit the initial condition to "P(1982) =
%    Pi".  Choose Analytic tools/IVP solution from the menu bar. If
%    desired, choose Manipulate/Simple or Manipulate/Simplify from
%    the Analytic solution window's menu bar.
%
%    To compare plots of the solutions of dP/dt = kP, P(0) = 100,
%    with k = 0.01 and k = 0.05, edit the initial condition as
%    shown and set k = 0.05, say.  (Remember to touch the ENTER key
%    after each edit on Windows systems.)
%
%    From the First-order equation menu bar, choose Graphical
%    tools/Solution plot vs. t.  In the resulting Plot solution
%    window, set Stop at t = 25, say.  Click Plot.
%
%    To plot the solution corresponding to k = 0.01, return to the
%    First-order equation window and edit the k value to 0.01.  In
%    the Plot solution window, select the Plot on/figure no.
%    radio button, enter the figure number, then click Plot.
%    (Remember to touch ENTER on Windows systems after entering
%    the figure number.)
%
%    MORE: To annotate the two curves in your figure, click
%    the letter "A" in the tool bar at the top of the figure to
%    add text to the figure.  Click the cursor near the upper
%    curve, type "k = 0.05", then click again to end text entry.
%    Repeat near the lower curve to label it "k = 0.01".
%    Experiment with some of the other plot editing tools before
%    you print the figure.  For more information, select
%    Help/Editing Plots from the figure menu bar.
%
% >> Figure 2.4
%
%    From the First-order equation menu bar, choose Equation/From
%    list/Emigration.  Choose Graphical tools/Direction field.
%    Click the Plot button in the Direction field window.
%
%    To draw other solution trajectories, select the Plot
%    on/figure no. radio button and enter the number of the target
%    figure.  Edit the initial value in the First-order equation
%    window, then click the Plot button in the Direction field
%    window.  Alternatively, select the Initial value-Click on
%    figure radio button and click the Plot button. Then position
%    the cursor over the desired initial point in the direction
%    field and click to begin plotting.
%
%    MORE: From the First-order equation menu bar, select
%    Analytic tools/Steady state(s).  Use the value that appears in
%    the Steady state window as the initial value in the
%    First-order equation window.  How should the corresponding
%    trajectory behave?  Select the Initial value-Use entered value
%    radio button in the Direction field window, then click the
%    Plot button to see if your prediction is correct.
%
% >> Figure 2.9
%
%    From the First-order equation menu bar, choose Equation/From
%    list/Logistic.  Choose Graphical tools/Direction field. Edit
%    the initial value as desired; e.g., to P(0) = 0.25.  Click the
%    Plot button in the Direction field window.
%
%    To see trajectories from other initial values on the same plot,
%    select the Plot on/figure no. radio button in the Direction
%    field window and enter the number of the target figure.  Edit
%    the initial value in the First-order equation window; e.g.,
%    to P(0) = 3.0. Then click the Plot button in the Direction
%    Field window.
%
% >> Example 13
%
%    From the First-order equation menu bar, choose Equation/From
%    list/Heat flow.  Then edit the equation to add the additional
%    furnace term F(T)/cm,
%
%    -(A*k/c*m)*(T - Tout) + (R*(1 + sign(20-T)))/(2*c*m)
%
%    Click the Add parameter button and enter R = .4 in the boxes
%    that appear.
%
%    From the menu bar, choose Numerical tools/Approx. solution of
%    IVP.  In the numerical approximation window that appears,
%    select the Euler method and set the step size to 5.  Click the
%    Start button to generate the numerical approximation.
%
%    To compare the Euler approximation with a more accurate
%    method, select it (e.g., Adaptive: Runge-Kutta 4/5) in the
%    Method drop-down box.  Select the Plot on/figure no. radio
%    button, enter the number of the target figure (remember to
%    touch ENTER on Windows systems), then click the Start button.
%
%
% >> Figure 2.14
%
%    From the System of first-order equations menu bar, choose
%    Equation/From list/Predator-prey.  From the menu bar, choose
%    Numerical tools/Approx. solution of IVP.  Select the Euler
%    method and set the step size to 1.  Click Start.  (The figure
%    you obtain is not the same as the upper graph in figure 2.14;
%    that figure was erroneously computed with alpha = 0.0009, beta
%    = 0.0011.  Change those values to see for yourself.)
%
%    To obtain the lower plot in figure 2.14, change the initial
%    values to F(0) = 1, R(0) = 1 in the System of first-order
%    equations window.  Then click the Start button in the
%    Numerical approximation of IVP window.
%
%
%  textbook - Double click here for textbook help contents
%
%  See also ABOUT, CONTENTS, TEXTBOOK

% Copyright 1999, 2000 Paul Davis.
% For nonprofit educational use only
