% Chap3 - Chapter 3 textbook help for DELab
%
%           Differential Equations: Modeling with Matlab
%                  Paul Davis, Prentice Hall 1999
%
% >> Euler method
%
%    To apply Euler or any other numerical method to an
%    initial-value problem, select the menu item Numerical
%    tools/Approx. solution of IVP from the Equation window.
%    Select Euler or another method from the drop-down Method box
%    in the Approximate solution of IVP window. Note that the
%    available methods include Heun and Runge-Kutta 4 as well as
%    Matlab's various adaptive methods; the latter adapt the
%    choice of step size to the problem at hand, unlike the
%    simpler method studied in this text.
%
% >> Figure 3.2
%
%    Select Equation/1st-order from the DELab window.  From the
%    resulting Equation window, select Equation/From list/Heat
%    loss. Set the initial value to T(0) = 20.
%
%    Select Numerical tools/Visual demo's. Choose the Euler method
%    from the drop-down Method box.  Set the final time to 350 min
%    and the step size to 50 min.  Click the Start button.  Press
%    any key (first move the cursor into the Matlab window on Unix
%    systems) to see subsequent steps.
%
% >> Table 3.4
%
%    Select Equation/1st-order from the DELab window.  From the
%    resulting Equation window, select Equation/From list/Simple
%    population. Edit the parameter and initial value to read k =
%    0.0282 and P(1978) = 115.4.
%
%    To find the value of the exact solution of the initial-value
%    problem at t = 2008, select Analytic tools/IVP solution from
%    the menu bar of the Equation window.  An Analytic solution
%    window will appear with a formula for the exact solution.
%    Select Manipulate/Use in MATLAB as/In-line function.  You will
%    see a message such as, "This solution is available in MATLAB
%    as the in-line function P_1(t)."
%
%    Similar information will appear in the MATLAB command window.
%    In the command window, save the value of the exact solution at
%    t = 2008 in a variable named Pexact by issuing the command
%
%        Pexact = P_1(2008)
%
%    MATLAB will reply
%
%       Pexact =
%
%         268.9174
%
%    To find the first numerical approximation, select Numerical
%    tools/Approx. solution of IVP from the Equation window. In
%    the resulting Numerical approximation of IVP window, choose
%    the Heun/RK2 method from the drop-down Method box. Set the
%    final time to 2008 and the step size to 10 yr. Under Output
%    options, select Graphical-None.  Check the Numerical-Save
%    values in MATLAB workspace box.  Click the Start button.
%
%    You will see a message such as, "The approximate solution is
%    available in MATLAB in the arrays t3 (t values) and P_3
%    (approximate solution values)."  (The number 3 is not a
%    subscript; it is simply a label to distinguish these
%    variables from others.)  Remember those names, and click OK
%    to close the message box. To see those values in the MATLAB
%    command window, type
%
%        [t3 P_3]
%
%    The values of the two-column matrix [t3 P_3] will be listed.
%    (Why are four sets of values listed if the method only took
%    three steps?)
%
%    The value of the Heun approximation at t = 2008 is the last,
%    or fourth, value in the P_3 column.  One way to obtain only
%    that value is to type in the MATLAB command window
%
%        P_3(4)
%
%    An equivalent but more general way is to type
%
%        P_3( length(P_3) )
%
%    because length(P_3) is the length of the P_3 array;
%    length(P_3) = 4.
%
%    Hence, for any similar numerical result, regardless of the
%    step size (table 3.4 uses 10, 5, 2.5, ...), the error in the
%    numerical approximation can be found with the MATLAB command
%
%        error = abs( Pexact - P_3(length(P_3)) )
%
%    Compare your result with the first entry in the Error (third)
%    column of table 3.4.
%
%    The first entry in the fourth column is obtained with the
%    command
%
%        error_on_delt2 = error/10^2
%
%    To find the next row of the table, return to the Numerical
%    approximation of IVP window, change the step size to 5
%    (remember to touch ENTER on Windows systems), and click Start
%    to produce another table of approximate solution values.
%    Repeat the preceding MATLAB commands to find the error, etc.
%
%    Hint: issue the command
%
%        clear t3 P_3
%
%    before calculating a new approximate solution; that new
%    solution will be given the same name as the old one you just
%    erased. Then the commands to calculate the error can be
%    recalled by using the up and down arrow keys.  When you see
%    the command you want, press ENTER to execute it.
%
% >> Runge-Kutta method
%
%    To apply the Runge-Kutta method, select a Numerical tool from
%    the menu bar of the Equation window, then click the down arrow
%    on the side of the Method window and highlight Runge-Kutta 4.
%
% >> Example 12
%
%    From the DELab menu bar, select Equation/1st-order.  In the
%    resulting Equation window, edit the equation to read
%
%       dy/dt = y^3 - y
%
%    Edit the initial value to attempt to reproduce one of the
%    curves in figure 3.14; e.g., y(0) = 0.9 for curve a. Delete
%    any parameters and their values.  Remember to touch ENTER on
%    Windows systems after making the last of these changes.
%
%    From the Equation window menu bar, select Graphical
%    tools/Solution plot vs t.  Click the Plot button to draw the
%    solution curve.  Does it compare well with curve a in figure
%    3.14?  If you are uncertain, try setting the "Stop at t = "
%    value to better show the curve; a good choice is Stop at t =
%    4. (Remember to touch the ENTER key on Windows systems after
%    making the change.)
%
% >> Example 13
%
%    From the DELab menu bar, select Equation/1st-order.  To
%    produce a figure similar to figure 3.16, select Equation/From
%    list/Simple population from the menu bar of the resulting
%    Equation window.  From the same menu bar, choose Graphical
%    tools/Direction field.
%
%    If desired, adjust the maximum t and P values and the minimum
%    P value in the Direction field window; e.g., to display both
%    positive and negative values of P as shown in figure 3.16,
%    set Min P = -600. Click the Initial value-Click on figure
%    radio button. Click the Plot button to draw the direction
%    field.
%
%    To draw a solution trajectory on the direction field, move
%    the cursor to the desired starting point and click.  To draw
%    another trajectory on the same diagram, select the Plot
%    on/figure no. radio button, enter the desired figure number,
%    then click the Plot button in the Direction field window.
%    Place the cursor over the new initial point in the direction
%    field diagram and click again.
%
%    To draw the corresponding phase line, select Graphical
%    tools/Phase line from the Equation window.  Edit the Min P
%    value to -600.  Click the Plot button to display the phase
%    line.  (The phase line will appear in a separate figure, not
%    on the direction field as the text suggests.)
%
%
% textbook - Double click here for textbook help contents.
%
% See also ABOUT, CONTENTS, TEXTBOOK

% Copyright 1999, 2000 Paul Davis.
% For nonprofit educational use only
