function f_evalue( action, n, A, V, D, titlestring )

% f_evalue - Formats and manipulates matrix evalues and
% evectors, then redisplays via call to w_evalue.

switch action  %
case 'asis'
   % do nothing
case 'simple'

   for i = 1:(n*n)
      V{i} = simple( V{i} );
   end

   for i = 1:n
      D{i} = simple( D{i} );
   end

case 'simplify'
   for i = 1:(n*n)
      V{i} = simplify( V{i} );
   end

   for i = 1:n
      D{i} = simplify( D{i} );
   end

case '4digits'
   for i = 1:(n*n)
      V{i} = vpa( V{i}, 4 );
   end

   for i = 1:n
      D{i} = vpa( D{i}, 4 );
   end

case '8digits'
   for i = 1:(n*n)
      V{i} = vpa( V{i}, 8 );
   end

   for i = 1:n
      D{i} = vpa( D{i}, 8 );
   end

case 'pretty'
   evalin( 'base', 'syms xxxval xxxvec' );
   assignin( 'base', 'xxxval', 'D' );
   assignin( 'base', 'xxxvec', 'V' );
   disp( ['Pretty eigenvalue formula:' ] );
   evalin( 'base', 'class( xxxval )' );
   evalin( 'base', 'pretty( xxxval )' );
   disp( ['Pretty eigenvector formula:' ] );
   evalin( 'base', 'pretty( xxxvec )' );
   % Announce availability of the pretty-print solution.
   msgbox( 'The pretty-print eigenvalues and eigenvectors are displayed in the MATLAB command window.', ...
      'Pretty-print' );
   evalin( 'base', 'clear xxxval' );
   evalin( 'base', 'clear xxxvec' );

end  % switch

w_evalue( n, A, V, D, titlestring );

%case { 'evaluate' 'pretty' 'symbolic' 'inline' ...
%   'latex' 'fortran' 'ccode' }
%
%   if nargin < 6, h0 = 1; end;
%
%   [ solname, number ] = UniqueName( ud.y, h0 );
%
%   % Define all symbols in solution and indepen variable as syms.
%   varstring = ListSym( solution, ud.t );
%   evalstring = [ 'syms ' varstring ];
%   evalin( 'base', evalstring );
%
%   % Assign solution string to solname.
%   neqn = length( ud.y );
%   if neqn == 1
%      evalstring = [ solname ' = ' char( solution{1} ) ];
%      solnsym = solution{1};
%      solnstring = char( solution{1} );
%   else
%      % Build string defining vector of symbols.
%      solnstring = [ char( solution{1} ) ];
%      solnsym = solution{1};
%
%      for i = 2:neqn
%         solnstring = [ solnstring '; ' char( solution{i} ) ];
%         solnsym = [ solnsym; solution{i} ];
%      end;
%
%      evalstring = [ solname ' = ' solnstring ];
%   end  %if
%
%   switch action
%   case 'symbolic'
%      disp( ['Symbolic solution formula ' solname ':' ] );
%      assignin( 'base', solname, solnsym );
%      evalin( 'base', solname );
%
%      if neqn == 1
%         vector = ' ';
%      else
%         vector = ' vector-valued ';
%      end;
%
%      msgbox( [ 'This solution is available in MATLAB as the',...
%         vector, 'symbolic expression ' solname '.' ], ...
%         'Solution in workspace' );
%
%   case 'inline'
%
%      % Identity input variables.
%      varlist = [];
%      for i = 1:neqn
%         inputvar =  char( findsym( solution{i} ) );
%         varlist = [ inputvar ',' varlist ];
%%         inputvar = sprintf( '''%s''', inputvar )
%%         varlist = [ varlist ' ' strrep( inputvar, ', ', ''', ''' ) ]
%      end;
%
%      % Delete spaces.
%      s = strrep( varlist, ' ', '' );
%      t = deblank( s );
%%      varlist = t( 1:(length( t ) - 1) );
%%      varlist = strrep( varlist, ', ', ''', ''' );
%%      varlist = sprintf( '''%s''', varlist );
%
%      % Remove repeated symbols.
%      s = findstr( ',', varlist );
%      commas = [ 0 s ];
%      for i = 1:(length( commas ) - 1)
%         s = deblank( varlist( (commas(i) + 1):( commas(i + 1) - 1 ) ) );
%
%         if ~isempty( s )
%            % Does s appear again later in varlist?
%            for j = (i + 1):(length( commas ) - 1)
%               t = varlist( (commas(j) + 1):( commas(j + 1) - 1 ) );
%
%               if strcmp( s, t )
%                  % Replace string t with blanks.
%                  for k = commas(j):( commas(j + 1) - 1 )
%                     varlist( k ) = ' ';
%                  end;  % for
%               end;  % if
%
%            end;  % for
%
%         end;  % if
%
%      end;  % for
%
%      % Delete trailing comma and blanks, add quotes around variables within string.
%      s = varlist( 1:( length( varlist ) - 1 ) );
%      t = deblank( s );
%      varlist = strrep( t, ', ', ''',''' );
%
%      % Create in-line function.
%%      formula = [ char( solution{1} ) ];
%%      for i = 2:neqn
%%         formula = [ ', ' char( solution{i} ) ];
%%      end;
%      evalstring = sprintf( '%s  = inline( ''[%s]'', ''%s'' )', ...
%         solname, solnstring, varlist );
%      evalin( 'base', evalstring );
%
%      % Announce availability of this function.
%
%      if neqn == 1
%         vector = ' ';
%      else
%         vector = ' vector-valued ';
%      end;
%
%      msgbox( [ 'This solution is available in MATLAB as the',...
%         vector, 'in-line function ' solname '(' inputvar ').' ], ...
%         'Solution as in-line function' );
%      return;
%
%   case 'evaluate'
%      % Query for t value, param values (?).  Use subs.
%
%   case 'pretty'
%      assignin( 'base', solname, solnsym );
%      disp( ['Pretty solution formula:' ] );
%      evalin( 'base', [ 'pretty(' solname ')' ] );
%      % Announce availability of the pretty-print solution.
%      msgbox( 'The pretty-print solution is displayed in the MATLAB command window.', ...
%         'Pretty-print solution' );
%      evalin( 'base', [ 'clear ' solname ] );
%
%   case 'fortran'
%      assignin( 'base', solname, solnsym );
%      disp( [ 'Fortran representation of solution:' ] );
%      evalin( 'base', [ 'fortran(' solname ')' ] );
%      msgbox( 'A Fortran representation of this solution appears in the MATLAB command window.',...
%      'Fortran' );
%      evalin( 'base', [ 'clear ' solname ] );
%
%   case 'ccode'
%      assignin( 'base', solname, solnsym );
%      disp( [ 'C representation of solution:' ] );
%      evalin( 'base', [ 'ccode(' solname ')' ] );
%      msgbox( 'A C representation of this solution appears in the MATLAB command window.',...
%         'C code' );
%      evalin( 'base', [ 'clear ' solname ] );
%
%   case 'latex'
%      assignin( 'base', solname, solnsym );
%      disp( [ 'LaTeX representation of solution:' ] );
%      evalin( 'base', [ 'latex(' solname ')' ] );
%      msgbox( 'A LaTeX representation of this solution appears in the MATLAB command window.',...
%         'LaTeX' );
%      evalin( 'base', [ 'clear ' solname ] );
%   end   % switch
%
%   return;
%
%case 'plot'
%   % Create in-line function.
%   formula = [ char( solution{1} ) ];
%   for i = 2:neqn
%      formula = [ ', ' char( solution{i} ) ];
%   end;
%   evalstring = sprintf( '%s  = inline( ''%s'', ''%s'' )', ...
%      solname, formula, varlist );
%   evalin( 'base', evalstring );
%
%   % query for tf
%   ud = get( gcbf, 'UserData' );  % ???
%   figure; ezplot( formula, [ str2num( ud.t0 ), tf ] );
%
%end
%
%switch type
%case { 'de1', 'ide1' }
%   ProbCell = DECell( ud.y, ud.t, ud.f, ud.pname, ud.pvalue );
%   SolnCell = FormSolnCell( 'de', ud.y, ud.t, multsoln, solution );
%
%   switch type
%   case 'de1'
%      SolnCell = FormSolnCell( 'de', ud.y, ud.t, multsoln, solution );
%   case 'ide1'
%      SolnCell = FormSolnCell( 'ide', ud.y, ud.t, multsoln, solution );
%   end  % case
%
%   w_anlsoln( 'de1', multsoln, solution, ...
%      ProbCell, SolnCell );
%
%case { 'de2', 'ide2' }
%   ProbCell{1} = DE2String( ud.y{1}, ud.t, ud.f{1} );
%
%   switch type
%   case 'de2'
%      SolnCell = FormSolnCell( 'de', ud.y, ud.t, multsoln, solution );
%   case 'ide2'
%      SolnCell = FormSolnCell( 'ide', ud.y, ud.t, multsoln, solution );
%   end  % case
%
%   w_anlsoln( 'de2', multsoln, solution, ProbCell, SolnCell );
%
%case { 'ivp1', 'iivp1' }
%   EqnCell = DECell( ud.y, ud.t, ud.f, ud.pname, ud.pvalue );
%   n = length( EqnCell );
%   neqn = length( ud.y );
%   ProbCell = cell( n + 1 + neqn, 1 );
%
%   for i = 1:n
%      ProbCell{i} = EqnCell{i};
%   end
%
%   ProbCell{n + 1, 1} = '';
%
%   for i = 1:neqn
%      ProbCell{n + 1 + i, 1} = ...
%         [ ud.y{i} '(' ud.t0 ') = ' ud.y0{i} ];
%   end
%
%   switch type
%   case 'ivp1'
%      SolnCell = FormSolnCell( 'de', ud.y, ud.t, multsoln, solution );
%   case 'iivp1'
%      SolnCell = FormSolnCell( 'ide', ud.y, ud.t, multsoln, solution );
%   end  % case
%
%   w_anlsoln( 'ivp1', multsoln, solution, ProbCell, SolnCell );
%
%case { 'ivp2', 'iivp2' }
%   % Form cell containing problem.
%   ProbCell = cell( 4, 1 );
%   ProbCell{1, 1} = DE2String( ud.y{1}, ud.t, ud.f{1} );
%   ProbCell{2, 1} = ' ';
%   ProbCell{3, 1} = [ '   ' char( ud.y{1} ) '(' char( ud.t0 ) ') = ' char( ud.y0{1} ) ];
%   ProbCell{4, 1} = [ '   ' char( ud.y{1} ) '''(' char( ud.t0 ) ') = ' char( ud.y0{2} )];
%
%   switch type
%   case 'ivp2'
%      SolnCell = FormSolnCell( 'de', ud.y, ud.t, multsoln, solution );
%   case 'iivp2'
%      SolnCell = FormSolnCell( 'ide', ud.y, ud.t, multsoln, solution );
%   end  % case
%
%   w_anlsoln( 'ivp2', multsoln, solution, ...
%      ProbCell, SolnCell );
%
%case 'ss1'
%   ProbCell = DECell( ud.y, ud.t, ud.f, ud.pname, ud.pvalue );
%   SolnCell = FormSolnCell( 'ss', ud.y, ud.t, multsoln, solution );
%   w_anlsoln( 'ss1', multsoln, solution, ...
%      ProbCell, SolnCell );
%
%case 'ss2'
%   ProbCell{1} = DE2String( ud.y{1}, ud.t, ud.f{1} );
%   SolnCell = FormSolnCell( 'ss', ud.y, ud.t, multsoln, solution );
%   w_anlsoln( 'ss2', multsoln, solution, ...
%      ProbCell, SolnCell );
%
%end
%
%% end - f_anlsoln
%
%
%%===========================
%
%function SolnCell = FormSolnCell( type, y, t, multsoln, solution )
%
%% SolnCell forms sol'n cell array given sym sol'n array
%% solution, a column array of sym.
%% type = de or ss; y, t are indep, depen variables
%% Pads a blank line in between each row of solution, puts spaces
%% around +, -, labels each row of solution
%
%nsolnrows = length( solution );
%leny = length( y );
%label = cell( leny, 1 );
%% multsoln = nsolnrows/leny;   % multiplicity of solution
%
%switch type
%case { 'de', 'ide' }
%    for i = 1:leny
%        varname{i} = [ char( y{i} ) '(' char( t ) ')' ];
%    end
%
%   switch type
%   case 'de'
%      solnlabel = 'Solution ';
%      relation = ' = ';
%
%   case 'ide'
%      solnlabel = 'Implicit solution ';
%      relation = ': ';
%   end  % case
%
%case 'ss'
%    for i = 1:leny
%        varname{i} = [ char( y{i} ) '_ss' ];
%    end
%    solnlabel = 'Equilibrium ';
%    relation = ' = ';
%end  % switch
%
%if nsolnrows == 1
%   SolnCell = cell(1, 1);
%   SolnCell{1, 1} = [ varname{1} relation char( solution{1} ) ];
%else
%
%   if multsoln == 1
%      SolnCell = cell( multsoln*(2*nsolnrows - 1), 1 );
%
%
%      for i = 1:(nsolnrows - 1)
%          SolnCell{2*i - 1, 1} = ...
%             [ varname{i} relation char( solution{i} ) ];
%          SolnCell{2*i, 1} = ' ';  % blank line
%      end;
%
%      i = nsolnrows;
%      SolnCell{2*nsolnrows - 1, 1} = ...
%         [ varname{i} relation char( solution{i} ) ];
%   else
%      SolnCell = cell( 2*leny + 2*multsoln, 1 );
%
%      cellrow = 1;
%
%      for j = 1:multsoln
%         SolnCell{ cellrow, 1 } = [ solnlabel num2str( j ) ];
%         SolnCell{ cellrow + 1, 1 } = ' ';
%         cellrow = cellrow + 2;
%
%         for i = 1:leny
%            SolnCell{cellrow, 1} = ...
%               [ '   ' varname{ i } relation char( solution{(j - 1)*leny + i} ) ];
%            SolnCell{cellrow + 1, 1} = ' ';  % blank line
%            cellrow = cellrow + 2;
%         end;
%
%      end  % for
%
%   end  % if
%
%end  % if
%
%s = strrep( SolnCell, '-', ' - ' );
%SolnCell = strrep( s, '+', ' + ' );
%
%% end FormSolnCell
%
%%===========================
%
%function ProbCell = DECell( y, t, f, pname, pvalue )
%
%% DECell forms cell 'dy/dt = f' with parameter values
%% y, t, fstring are cell arrays. Puts spaces around +, -.
%
%s = strrep( f, '-', ' - ' );
%f = strrep( s, '+', ' + ' );
%neqn = length( f );
%ProbCell = cell( neqn, 1 );
%
%if length( t ) == 1
%   slashd = '/d';
%else
%   slashd = '/d ';
%end  % if
%
%for i = 1:neqn
%   if length( y{i} ) == 1
%      space = '';
%   else
%      space = ' ';
%   end
%
%   ProbCell{i, 1} = [ 'd' space y{i} space slashd t ' = ' f{i} ];
%end
%
%% List parameters for which values have been entered.
%count = 1;
%for i = 1:length( pname )
%   if ~isempty( pvalue{i} )
%      ProbCell{neqn + count, 1} = [ '    ' pname{i} ' = ' pvalue{i} ];
%      count = count + 1;
%   end
%end
%
%% end DECell
%
%%===========================
%
%function s = DE2String( y, t, fstring )
%
%% DE2String forms string 'd^2 y/dt^2 = fstring'
%% y, t, fstring are strings; Puts spaces around +, -.
%
%% y
%% class( y )
%% t
%% class( t )
%% fstring
%% class( fstring )
%
%s = strrep( fstring, '-', ' - ' );
%fstring = strrep( s, '+', ' + ' );
%% s = [ 'd^2 ' y '/dt^2  = ' fstring ];
%s = sprintf( 'd^2%s/dt^2 = %s', char( y ), char( fstring ) );
%
%% end DE2String
%
%%===========================
%
%function [ solname, num ] = UniqueName( y, h0 );
%
%% Constructs unique variable name y_num or y_vectornum from first
%% entry in variable name cell array y, ideally using the figure
%% number h0 of the calling window.  "Unique" is among base
%% variables.
%
%curvar = evalin( 'base', 'who' );
%
%if length( y ) == 1
%   vector = '_';
%   varname = char( y{1} )
%else
%   vector = '_vec';
%   varname = y{1}
%end;
%
%num = h0;
%solname = [ varname vector num2str( num ) ];
%a = { [ '' solname '' ] };
%
%while( ismember( a , curvar ) )
%   num = num + 1;
%   solname = [ varname vector num2str( num ) ];
%   a = { [ '' solname '' ] };
%end; % while
%
%% end  UniqueName
%
%%===========================
%
%function varstring = ListSym( solution, tname );
%
%% Creates space-separated list of symbolic variables in solution,
%% a cell array of symbols.  Adds the symbol in t as well.
%
%% Define all symbols in solution and indepen variable as syms.
%varstring = [];
%for i = 1:length( solution )
%   varstring = [ varstring ' ' strrep( findsym( solution{i} ), ',', '' ) ];
%end;
%varstring = [ varstring ' ' ];
%
%%Add tname to symbol list if not there already.
%if ~findstr( [ ' ' tname ' ' ], varstring )
%   varstring = [ varstring ' ' tname ];
%end;
%
%% end ListSym
