function order2H = f_order2( varargin )

% Callback functions for order 2 ODE window in DELab
% Useage: f_order2 action number


% Set of actions
S = { 'FromList', 'Save',...         % w_order2 menu ===
   'AnlSolveODE', 'AnlSolveIVP', 'StdyState',...
   'numivp', 'visdemo',...
   'Dfield', 'PlotIVP',...
   'HelpLocal', 'HelpText',...
   'ok', 'close', 'quit'...          % push button selections
   'y_edit', 't_edit', 'f_edit',...  % edit box actions
   'p1name_edit', 'p1value_edit',...
   'p2name_edit', 'p2value_edit',...
   't0_edit', 'y0_edit', 'all_edit',...
   'Euler', 'Heun', 'RK4',...        % w_numcntrl menu ===
   'ode45', 'ode113',...
   'ode15s'...
   'NumHelp',...,
   'start', 'stop',...                % push buttons
   'tf_edit', 'deltat_edit',...       % edit boxes
   'NumStep_edit', 'ymin_edit'...
   'ymax_edit',...
   'StepSize_radio', 'NumStep_radio',... % radio buttons
   'UseEnteredIC_radio', 'ClickIC_radio',...
   'NewFig_radio', 'CurrentFig_radio',...
   'dfield_check', 'high_check',...    % check boxes
    'yaxis_check' };

switch nargin
case 0
   action = 'initialize';
%   lightgray = [ 0.8 0.8 0.8 ];
%   darkgray = [0.752941176470588 0.752941176470588 0.752941176470588];
%   white = [ 1 1 1 ];
%   black = [ 0 0 0 ];
case 1
   action = varargin{1};
case 2
   action = varargin{1};
   eqn = str2num( varargin{2} );  % Equation from defaultlist
end

switch action
case 'initialize'
   load o2list;
   ud.id = defaultlist{eqn}.id;
   ud.y = defaultlist{eqn}.y;
   ud.t = defaultlist{eqn}.t;
   ud.f = defaultlist{eqn}.f;
   ud.numeqn = length( ud.f );
   ud.pname = defaultlist{eqn}.pname;
   ud.pvalue = defaultlist{eqn}.pvalue;
   ud.nump = length( ud.pname );
   ud.t0 = defaultlist{eqn}.t0;
   ud.y0 = defaultlist{eqn}.y0;
   ud.tf = defaultlist{eqn}.tf;
   ud.deltat = defaultlist{eqn}.deltat;
   ud.NumStep = defaultlist{eqn}.NumStep;
   ud.ymin = defaultlist{eqn}.ymin;
   ud.ymax = defaultlist{eqn}.ymax;
   ud.method = defaultlist{eqn}.method;

   ud.Handle.order1 = -1;

%   % pre-allocate storage for w_numcntrl handles
%   ud.Handle.StepSize_radio = -1;
%   ud.Handle.StepSize_box = -1;
%   ud.Handle.NumStep_radio = -1;
%   ud.Handle.NumStep_box = -1;
%   ud.Handle.UseEnteredIC_radio = -1;
%   ud.Handle.ClickIC_radio = -1;
%   ud.Handle.NewFig_radio = -1;
%   ud.Handle.CurrentFig_radio = -1;
%   ud.Handle.deltat_frame = -1;
%   ud.Handle.dfield_check = -1;
%   ud.Handle.high_check = -1;
%   ud.Handle.tf_box = -1;
%   ud.Handle.ymin_box = -1;
%   ud.Handle.ymax_box = -1;
%   ud.Handle.yaxis_check = -1;
%
   % pre-allocate storage for GUI figure handles
   ud.Handle.order2 = -1;
%   ud.Handle.numcntrl = -1;
%   ud.Handle.targetfig = -1;
%   ud.Handle.dfld = [];

   h = w_order2( ud );
   set( h, 'HandleVisibility', 'CallBack' );
case 'FromDefaultList'
   ud = get( gcbf, 'Userdata' );
   oldnump = ud.nump;
%   load( 'd:\matlab5\toolbox\matlab\delab_dev\o2list.mat' )
   load o2list.mat;

   ud.y = defaultlist{eqn}.y;
   ud.t = defaultlist{eqn}.t;
   ud.f = defaultlist{eqn}.f;
   ud.pname = defaultlist{eqn}.pname;
   ud.pvalue = defaultlist{eqn}.pvalue;
   ud.nump = length( ud.pname );
   ud.t0 = defaultlist{eqn}.t0;
   ud.y0 = defaultlist{eqn}.y0;
   ud.tf = defaultlist{eqn}.tf;
   ud.deltat = defaultlist{eqn}.deltat;
   ud.NumStep = defaultlist{eqn}.NumStep;
   ud.ymin = defaultlist{eqn}.ymin;
   ud.ymax = defaultlist{eqn}.ymax;
   ud.method = defaultlist{eqn}.method;

   ud.Handle.order1 = -1;

   set( gcbf, 'Userdata', ud );

   set( ud.Handle.y_box, 'String', ud.y{1} );

   set( ud.Handle.yparen_box(1), 'String', [ char(ud.y{1}) '(' ] );
   set( ud.Handle.yparen_box(2), 'String', [ char(ud.y{1}) '''(' ] );

   set( ud.Handle.t_box, 'String', ud.t );
   set( ud.Handle.f_box, 'String', ud.f );

   if oldnump == ud.nump

      for i = 1:oldnump
         set( ud.Handle.pname_box(i), 'String', ud.pname{i} );
         set( ud.Handle.pvalue_box(i), 'String', ud.pvalue{i} );
         % Why can't assign cell arrays here?
      end;

   elseif oldnump < ud.nump

      % Replace equation window with one having
      % more parameter boxes.
      close( gcbf );
      h = w_order2( ud );
      set( h, 'HandleVisibility', 'CallBack' );

      return;

   elseif oldnump > ud.nump

      % Use needed parameter boxes; blank the rest.
      % Add additional empty parameters.
      for i = 1:ud.nump
         set( ud.Handle.pname_box(i), 'String', ud.pname{i} );
         set( ud.Handle.pvalue_box(i), 'String', ud.pvalue{i} );
      end;

      for i = (ud.nump + 1):oldnump
         set( ud.Handle.pname_box(i), 'String', '' );
         set( ud.Handle.pvalue_box(i), 'String', '' );
         ud.pname{i} = '';
         ud.pvalue{i} = '';
      end;

      ud.nump = oldnump;
      set( gcbf, 'UserData', ud );

   end;

   set( ud.Handle.t0_box, 'String', ud.t0 );
   set( ud.Handle.y0_box(1), 'String', ud.y0{1} );
   set( ud.Handle.y0_box(2), 'String', ud.y0{2} );

   ud.NumStep = NStep( ud.t0, ud.tf, ud.deltat );

   % Check some other way to see if this fig is still open
   % or set ud.Handle to -1 before closing.
%   if ud.Handle.numcntrl > 0
%      set( ud.Handle.NumStep_box, 'String', ud.NumStep );
%      set( ud.Handle.StepSize_box, 'String', ud.deltat );
%      set( ud.Handle.ymin_box, 'String', ud.ymin );
%      set( ud.Handle.ymax_box, 'String', ud.ymax );
%      set( ud.Handle.numcntrl, 'Userdata', ud );
%   end;

case 'Save'
   sorry;
case 'AnlSolveODE'
   set( gcf, 'Pointer', 'watch' );
   ud = get( gcbf, 'Userdata' );
   fstring = deblank ( ud.f{1} );

   % Replace y' or dy/dt with Dy.
   Dy = [ 'D' char(ud.y{1}) ];
   yprime = [ char(ud.y{1}) ''''];

   if isempty( findstr( yprime, char( fstring ) ) )
      % Used dy/dt instead of y'
      yprime = [ 'd' char( ud.y{1} ) '/d' ud.t ];
   end;

   fstring = strrep( fstring, yprime, Dy );

   % Substitute parameter values
   fstring = de2prm2val( fstring, ud.pname, ud.pvalue );
   solvestr = [ 'D2' char( ud.y{1} ) ' = ' fstring ];

   try
      lastwarn( '' );
      implicit = 0;
      s = dsolve( solvestr, ud.t );

         if ~isempty( lastwarn )
            % Implicit solution, most likely
            implicit = 1;
            warndlg( lastwarn, 'Warning' );
            lastwarn( '' );
         end

   catch
      warndlg( 'No compact analytic solution or faulty  problem formulation', 'Warning' );
      set( gcbf, 'Pointer', 'arrow' );
      return;
   end

   if ~isempty( s )
      solution = dsolve2cell( s );
      multsoln = length( solution );
      set( gcbf, 'Pointer', 'arrow' );

      if implicit
         f_anlsoln( 'asis', 'ide2', multsoln, solution );
      else
         f_anlsoln( 'asis', 'de2', multsoln, solution );
      end  % if

   else
      warndlg( 'No explicit solution could be found.', 'Warning' );
      set( gcbf, 'Pointer', 'arrow' );
      return;
   end

case 'AnlSolveIVP'
   set( gcf, 'Pointer', 'watch' );
   ud = get( gcbf, 'Userdata' );
   fstring = deblank ( ud.f{1} );

   % Replace y' or dy/dt with Dy.
   Dy = [ 'D' char(ud.y{1}) ];
   yprime = [ char(ud.y{1}) ''''];

   if isempty( findstr( yprime, char( fstring ) ) )
      % Used dy/dt instead of y'
      yprime = [ 'd' char( ud.y{1} ) '/d' ud.t ];
   end;

   fstring = strrep( fstring, yprime, Dy );

   % Substitute parameter values
   fstring = de2prm2val( fstring, ud.pname, ud.pvalue );

   solvestr = [ 'D2' char( ud.y{1} ) ' = ' fstring ];
   icstring = [ char( ud.y{1} ) '(' ud.t0 ') = ' char( ud.y0{1} ) ];
   icstring = [ icstring ', D' char( ud.y{1} ) '(' ud.t0 ') = ' char( ud.y0{2} ) ];
   solvestr = [ solvestr ', ' icstring ];

   try
      lastwarn( '' );
      implicit = 0;
      s = dsolve( solvestr, ud.t );

      if ~isempty( lastwarn )
         % Implicit solution likely
         implicit = 1;
         warndlg( lastwarn, 'Warning' );
         lastwarn( '' );
      end

   catch
      warndlg( 'No compact analytic solution or faulty  problem formulation', 'Warning' );
      set( gcbf, 'Pointer', 'arrow' );
      return;
   end

   if ~isempty( lastwarn )
      warndlg( lastwarn, 'Warning' );
      lastwarn( '' );
   end

   if ~isempty( s )
      solution = dsolve2cell( s );
      multsoln = length( solution );
      set( gcbf, 'Pointer', 'arrow' );

      if implicit
         f_anlsoln( 'asis', 'iivp2', multsoln, solution );
      else
         f_anlsoln( 'asis', 'ivp2', multsoln, solution );
      end  % if

   else
      warndlg( 'No explicit solution could be found.', 'Warning' );
      set( gcbf, 'Pointer', 'arrow' );
      return;
   end

case 'StdyState'
   set( gcf, 'Pointer', 'watch' );
   ud = get( gcbf, 'Userdata' );
   fstring = deblank ( ud.f{1} );

   % Replace y' or dy/dt with Dy.
   Dy = [ 'D' char(ud.y{1}) ];
   yprime = [ char(ud.y{1}) ''''];

   if isempty( findstr( yprime, char( fstring ) ) )
      % Used dy/dt instead of y'
      yprime = [ 'd' char( ud.y{1} ) '/d' ud.t ];
   end;

   fstring = strrep( fstring, yprime, Dy );

   % Substitute parameter values,
   fstring = de2prm2val( fstring, ud.pname, ud.pvalue );

   % Set Dy = 0.
   solvestr = [ char( subs( fstring, Dy, '0' ) ) ' = 0' ];
   set( gcf, 'Pointer', 'arrow' );

   if char( diff( solvestr, ud.t ) ) ~= '0'
      errordlg( ['This equation has no steady states: ' ud.t ' appears explicity in it.' ],'Error' );
      set( gcf, 'Pointer', 'arrow' );
   else
      try
         lastwarn( '' );
         s = solve( solvestr, char( ud.y{1} ) );

         if ~isempty( lastwarn )
            warndlg( lastwarn, 'Warning' );
            lastwarn( '' );
         end

      catch
         warndlg( 'No explicit steady state could be found.', 'Warning' );
         set( gcbf, 'Pointer', 'arrow' );
         return;
      end

      solution = dsolve2cell( s );
      multsoln = length( solution );
      set( gcbf, 'Pointer', 'arrow' );
      f_anlsoln( 'asis', 'ss2', multsoln, solution );
   end;

case { 'numivp', 'phaseplane', 'plotvst', 'Equiv1stOrder' }
   hin = gcbf;
   ud2 = get( hin, 'Userdata' );  % 2nd-order equation
   ud1 = ud2;
   ud1.id = [ char( ud2.id ) ' - equivalent 1st-order system' ];
   ud1.numeqn = 2;
   yprimename = [ char( ud2.y{1} ) 'prime' ];
   ud1.y = { ud2.y{1}; yprimename };

   fstring = ud2.f{1};
      % Replace y' or dy/dt with yprimename.
   yprime = [ char(ud2.y{1}) ''''];

   if isempty( findstr( yprime, char( fstring ) ) )
      % Used dy/dt instead of y'
      yprime = [ 'd' char( ud2.y{1} ) '/d' ud2.t ];
   end;

   fstring = strrep( fstring, yprime, yprimename );

   ud1.f = cell(2, 1);
   ud1.f{1} = yprimename;
   ud1.f{2} = fstring;

   if ud2.Handle.order1 < 0   % No equiv 1st order system
      order1handle = f_order1( 'initialize_sys2', '-1', ud1 );  %open 1st-order system window
      ud2.Handle.order1 = order1handle;  % handle of equiv 1st order sys
      set( hin, 'UserData', ud2 );

      switch action
      case { 'numivp', 'phaseplane', 'plotvst' }
         msgbox( 'Second-order equation rewritten as equivalent first-order system in order to apply appropriate tool to it.', ...
         'Using first-order system' );

      end  % switch

   else
      % Equiv system already available at ud2.Handle.order1
      msgbox( 'Using the equivalent first-order system that is already available.', ...
      'Using first-order system' );
      order1handle = ud2.Handle.order1;
      figure( order1handle );
   end;

   % Open tool panel and set options as needed
   switch action
   case { 'numivp', 'phaseplane', 'plotvst' }
      f_order1( action, num2str( order1handle ) );
      ud1 = get( order1handle, 'UserData' );

      switch action
      case 'phaseplane'
         pud = get( ud1.Handle.phaseplane, 'UserData' );
         set( pud.Handle.show_nullclines, 'Checked', 'off' );
         set( pud.Handle.hide_nullclines, 'Checked', 'on' );

      case 'plotvst'
         pud = get( ud1.Handle.plotvst, 'UserData' );
         set( pud.Handle.showvar(1), 'Value', 1 );
         set( pud.Handle.showvar(2), 'Value', 0 );

      end  % case

   end  % switch

case 'AddParameter'
   ud = get( gcbf, 'Userdata' );
   ud.nump = ud.nump + 1;
   ud.pname = ud.pname(:);
   ud.pname = [ ud.pname; { '' } ];
   ud.pvalue = ud.pvalue(:);
   ud.pvalue = [ ud.pvalue; { '' } ];
   close( gcbf );
   h = w_order2( ud );
   set( h, 'HandleVisibility', 'CallBack' );
case 'close'
% Following produces
% ??? Attempt to reference field of non-structure array 'ud'.
%   ud = get( gcbo, 'UserData' );
%
%   if ~isempty( ud.Handle.targetfig )
%      close( ud.Handle.targetfig );
%   end;

   h = gcbo;
   delete( get( h, 'Children' ) );
   close gcbf;  % close the window that called f_order2
case 'quit'
   % are you sure?
   close all;
   case 'y_edit'
      ud = get( gcbf, 'Userdata' );
      ud.y = cell(1, 1);
      ud.y{1} = get( ud.Handle.y_box(1), 'String' );
      set( ud.Handle.yparen_box(1), 'String', [ char(ud.y{1}) '( ' ] );
      set( ud.Handle.yparen_box(2), 'String', [ char(ud.y{1}) '''( ' ] );
      set( gcbf, 'Userdata', ud );
      % test that string can be eval'd
   %   if ud.Handle.numcntrl > 0
   %      set( ud.Handle.numcntrl, 'Userdata', ud );
   %   end;

case { 't_edit' 'f_edit' 'pname_edit' 'pvalue_edit' ...
   't0_edit' 'y0_edit' }
   ud = get( gcbf, 'Userdata' );

%   % Must change entry in order 1, not edit
%   if ud.Handle.order1 > 0
%      % Edit entry in equivalent order 1 eqn window
%      f_order1( action, num2str( ud.Handle.order1 ) );
%   end  % if

   switch action
   case 't_edit'
      ud.t = get( ud.Handle.t_box, 'String' );
      set( gcbf, 'Userdata', ud );

   case 'f_edit'
      ud.f = cell( 1, 1 );
      ud.f{1} = char( get( ud.Handle.f_box(1), 'String' ) );
      set( gcbf, 'Userdata', ud );

   case 'pname_edit'
      ud.pname = get( ud.Handle.pname_box, 'String' );
      set( gcbf, 'Userdata', ud );

   case 'pvalue_edit'
      % check only digits, ., blanks entered
      ud.pvalue = get( ud.Handle.pvalue_box, 'String' );
      set( gcbf, 'Userdata', ud );

   case 't0_edit'
      ud.t0 = get( ud.Handle.t0_box(1), 'String' );
   %   fprintf( 1,...
   %   'Before NStep, ud.NumStep = %s, ud.deltat = %s, ud.t0 = %s, ud.tf = %s\n', ud.NumStep, ud.deltat, ud.t0, ud.tf );
      ud.NumStep = NStep( ud.t0, ud.tf, ud.deltat );
   %   fprintf( 1,...
   %   'After NStep, ud.NumStep = %s, ud.deltat = %s, ud.t0 = %s, ud.tf = %s\n', ud.NumStep, ud.deltat, ud.t0, ud.tf );
      set( gcbf, 'Userdata', ud );

   case 'y0_edit'
      ud.y0 = get( ud.Handle.y0_box, 'String' );
      set( gcbf, 'Userdata', ud );
      set( ud.Handle.order2, 'Userdata', ud );

   end  % case

case 'tf_edit'
   ud = get( gcbf, 'Userdata' );
   ud.tf = get( ud.Handle.tf_box, 'String' );
   ud.NumStep = NStep( ud.t0, ud.tf, ud.deltat );
   set( ud.Handle.NumStep_box, 'String', ud.NumStep );
   set( ud.Handle.order2, 'UserData', ud );
   set( gcbf, 'Userdata', ud );
case 'deltat_edit'
   ud = get( gcbf, 'Userdata' );
   ud.deltat = get( ud.Handle.StepSize_box, 'String' );
   ud.NumStep = NStep( ud.t0, ud.tf, ud.deltat );
   set( ud.Handle.NumStep_box, 'String', ud.NumStep );
   set( ud.Handle.order2, 'UserData', ud );
   set( gcbf, 'Userdata', ud );
case 'NumStep_edit'
   ud = get( gcbf, 'Userdata' );
   ud.NumStep = get( ud.Handle.NumStep_box, 'String' );

   x = str2num( ud.NumStep );
   if ~isint( x ) | x < 0
      errordlg( ...
      [ 'ERROR: Enter a positive integer for the number of ' ud.method ' steps.'] );
   elseif x > 1e+4
      warndlg( ...
      [ 'Are you sure you want ' num2str( x ) ' ' ud.method ' steps?'],...
      'Warning'  );
   end;

   ud.deltat = DStep( ud.t0, ud.tf, ud.NumStep );
   set( ud.Handle.StepSize_box, 'String', ud.deltat );
   set( ud.Handle.order2, 'UserData', ud );
   set( gcbf, 'Userdata', ud );
case 'ymin_edit'
   ud = get( gcbf, 'Userdata' );
   ud.ymin = get( ud.Handle.ymin_box, 'String' );
   set( ud.Handle.order2, 'UserData', ud );
   set( gcbf, 'Userdata', ud );
case 'ymax_edit'
   ud = get( gcbf, 'Userdata' );
   ud.ymax = get( ud.Handle.ymax_box, 'String' );
   set( ud.Handle.order2, 'UserData', ud );
   set( gcbf, 'Userdata', ud );
case 'all_edit'
% start here - copy from f_order1.m
   ud = get( gcbf, 'Userdata' );

   f_order2 y_edit;
   f_order2 t_edit;
   f_order2 f_edit;
   f_order2 t0_edit;
   f_order2 y0_edit;
   f_order2 pname_edit;
   f_order2 pvalue_edit;

   % Update all edit box strings. (Not needed in Unix because edit box
   % callback is executed when focus leaves edit box.)
   % fprintf(1, '\nStart of all_edit\n' );
%   ud.y = cell(1, 1);
%   ud.y{1} = get( ud.Handle.y_box(1), 'String' );
%%   ud.y = get( ud.Handle.y_box, 'String' );
%   ud.t = get( ud.Handle.t_box, 'String' );
%   ud.f{1} = get( ud.Handle.f_box, 'String' );
%   ud.pname = get( ud.Handle.pname_box, 'String' );
%   ud.pvalue = get( ud.Handle.pvalue_box, 'String' );
%   ud.t0 = get( ud.Handle.t0_box(1), 'String' );
%   ud.y0 = get( ud.Handle.y0_box, 'String' );
   set( ud.Handle.order2, 'UserData', ud ); % ???
   set( gcbf, 'Userdata', ud );

otherwise
   fprintf( 'Error: f_order2 does not recognize the argument: %s\n', action );

end  % switch

% end f_order2

%===========================

function strout = subparam( strin, pname, pval )

% If a parameter value is given, substitutes its numeric value pval
% in place of its name pname in the string strin and returns strout.

if isempty( str2num( pval ) )
   % blanks in parameter value box
   strout = strin;
else
   strout = strrep( strin, pname, pval );
end

% end subparam

%===========================

function strout = de2prm2val( f, pname, pvalue )

% Substitutes values pvalue of parameters pname (cell arrays) into
% f.
% This function is local to
% f_order2.  Can't blindly use strrep; e.g. 's = 6' turns 'cos' into 'co6'.

strout = sym( char( f ) );
% digits(8);

for i = 1:length( pname )
   name = sym( pname{i} );
   value = pvalue{i};
   if ~isempty( value )
      % A parameter value has been entered. Substitute.
      strout = subs( strout, sym( name ), sym( value ) );
   end

end

strout = char( strout );
% digits(32);

% end de2prm2val

%===========================

function strout = vectorize( strin )

% Vectorizes operations in the string strin: replaces *, /, and ^
% with .*, ./, and .^ .

% Strip user-entered vector operations, if present, then
% re-enter them.  Don't use with symbolic functions, even though
% the array operations are supposed to be sym/overloaded.
strout = strrep( strin, '.*', '*' );
strout = strrep( strout, './', '/' );
strout = strrep( strout, '.^', '^' );
strout = strrep( strout, '*', '.*' );
strout = strrep( strout, '/', './' );
strout = strrep( strout, '^', '.^' );

% end vectorize

%===========================

function strout = prettytitle( strin )

% prettytitle removes . from .*, etc. and removes * for
% pretty figure title output.

% Strip vector operations and '*'
strin = strrep( strin, '.*', '*' );
strin = strrep( strin, './', '/' );
strin = strrep( strin, '.^', '^' );
strin = strrep( strin, '*', ' ' );

% pad around +/-
strin = strrep( strin, '+', ' + ' );
strout = strrep( strin, '-', ' - ' );

% end prettytitle

%===========================

function SolnCell = FormSolnCell( multsoln, solution )

% SolnCell forms sol'n cell array given sym sol'n array, multiplicity
% [multsoln 1] = size( solution ); class( solution ) = sym
% Pads a blank line in between each row of solution, puts spaces
% around +, -

SolnCell = cell( 2*multsoln - 1, 1 );

if multsoln == 1
   SolnCell{1} = char( solution );
else
   for i = 1:(multsoln - 1)
      SolnCell{2*i - 1} = char( solution(i, 1) );
      SolnCell{2*i} = ' ';  % blank line
   end;
   SolnCell{2*multsoln - 1} = char( solution(multsoln, 1) );
end;

s = strrep( SolnCell, '-', ' - ' );
SolnCell = strrep( s, '+', ' + ' );

% end FormSolnCell

%===========================

function deltat = DStep( t0, tf, n )

% DStep( t0, tf, n) returns (tf - t0)/n
% Input and output are all strings; checks for empty cases.

t0val = str2num( t0 );
tfval = str2num( tf );

if isempty( tfval ) | isempty( t0val )
   deltat = '';
elseif tfval <= t0val
   deltat = '';
else
   deltat = num2str( ( tfval - t0val  )/...
      str2num( n ) );
end;

% end DStep

%===========================

function NumStep = NStep( t0, tf, deltat )

% NStep( t0, tf, deltat) returns ceil( |tf - t0|/deltat )
% Input and output are all strings; checks for empty cases.

t0val = str2num( t0 );
tfval = str2num( tf );

if isempty( tfval ) | isempty( t0val )
   NumStep = '';
elseif tfval <= t0val
   NumStep = '';
else
   NumStep = num2str( abs( ceil( ( tfval - t0val  )/...
      str2num( deltat ) ) ) );
end;

% end NStep

%===========================

function ans = isint( x )

% isint( x ) returns 1 if x is an integer, 0 otherwise.


if class( x ) ~= 'double'
   ans = 0;
elseif ( x - floor( x) ) ~= 0
   ans = 0;
else
   ans = 1;
end;

% end isint

%===========================

%function SolvDraw( ud )
%
%% SolvDraw( ud ) draws figure of solution plot as requested by DELab
%% user.
%% ud is UserData from DELab.
%
%% Construct inline function and ode call arguments
%s = de2prm2val( ud );  %This is wrong argument string.
%fstring = vectorize( s );
%yp = inline( fstring, char( ud.t ), char( ud.y{1}) );
%
%set( ud.Handle.numcntrl, 'Pointer', 'watch' );
%
%% Figure set up
%if get( ud.Handle.NewFig_radio, 'Value' ) == 1
%   % Start a new figure.
%   t0 = str2num( ud.t0 );
%   tf = str2num( ud.tf );
%   yminold = 0;
%   ymaxold = 0;
%   ud.Handle.dfld = [];
%
%   if get( ud.Handle.yaxis_check, 'Value' ) == 1
%      % User entered yaxis limits for this new fig
%      yminold = str2num( ud.ymin );
%      ymaxold = str2num( ud.ymax );
%      a = [ t0 tf yminold ymaxold ];
%   elseif get( ud.Handle.yaxis_check, 'Value' ) == 0 ...
%      & get( ud.Handle.ClickIC_radio, 'Value' ) == 1
%      % No axes specified but user wants axes drawn
%      s = [ 'You must specify the ' char( ud.y{1} ) ' axis limits.' ];
%      errordlg( s, 'Error' );
%      return;
%   end;
%
%   ud.Handle.targetfig = figure;
%   NewDfldAxis = 1;  % Must draw a new axis for dir field.
%else
%   % Use current figure.
%   figure( ud.Handle.targetfig );
%   hold on;
%
%   % Have axis limits changed?
%   a = axis;
%   t0old = a(1, 1);
%   tfold = a(1, 2);
%   yminold = a(1, 3);
%   ymaxold = a(1, 4);
%   t0 = str2num( ud.t0 );
%   tf = str2num( ud.tf );
%
%   if get( ud.Handle.yaxis_check, 'Value' ) == 1
%      % Using preset y axis limits and entered t limits
%      ymin = str2num( char( ud.ymin ) );
%      ymax = str2num( char( ud.ymax ) );
%      a = [ t0 tf ymin ymax ];
%      axis( a );
%
%      if t0old ~= t0 | tf ~= tfold | ymin ~= yminold | ymax ~= ymaxold
%         NewDfldAxis = 1;
%      else
%         NewDfldAxis = 0;
%      end;
%
%   elseif  t0old ~= t0 | tf ~= tfold
%      % Using auto y axis limits but user changed t axis.
%      a = [ t0 tf yminold ymaxold ];
%      axis( a );
%      NewDfldAxis = 1;
%   else
%      axis auto;
%      NewDfldAxis = 0;
%   end;
%
%   if ~ishold
%      hold on;
%   end;
%
%end;
%
%% Direction field set up, if requested.
%if  get( ud.Handle.dfield_check, 'Value' ) == 1 ...
%   % Set number of d field subdivisions
%
%   if ( str2num( ud.NumStep ) ) > 0
%      numdraw = str2num( ud.NumStep );
%
%      switch numdraw
%      case ( numdraw == 1 | numdraw == 2 )
%         numdraw = 10;
%      case ( numdraw == 3 | numdraw == 4 )
%         numdraw = 12;
%      case ( numdraw >= 5 & numdraw <= 9 )
%         numdraw = 2*numdraw;
%      end;
%
%   else
%     numdraw = 10;
%   end;
%
%   % (Re)draw direction field here if click on IC, and if
%   % axes have changed (or are new).  Otherwise, d field (if requested) will be
%   % (re)drawn after solution is plotted, if necessary.
%   if get( ud.Handle.ClickIC_radio, 'Value' ) == 1 ...
%      & NewDfldAxis == 1
%
%      h = ud.Handle.dfld;
%      if ~isempty( h )
%         % Hide prior direction field.
%         delete( h );
%%         set( ud.Handle.dfld, 'Visible', 'off' );
%      end;
%
%%      if isempty( a )
%%         % Axis has not been specified.
%%         s = [ 'You must specify the ' char( ud.y{1} ) ' axis limits.' ];
%%         errordlg( s, 'Error' );
%%         return;
%%      end;
%
%      ud.Handle.dfld = dfld( numdraw, a, yp );
%      NewDfldAxis = 0;
%   end;
%
%end;
%
%% Initial conditions
%if get( ud.Handle.UseEnteredIC_radio, 'Value' ) == 1
%   y0 = str2num( ud.y0 );
%   t0 = str2num( ud.t0 );
%else
%   % Click on figure
%   [t0 y0 ] = ginput(1);
%   StringCell = cell( 3, 1);
%   StringCell{1} = [ 'Starting at ' ];
%   StringCell{2} = [ '   ' ud.t ' = ' num2str( t0 ) ];
%   StringCell{3} = [ '   ' ud.y{1} ' = ' num2str( y0 ) ];
%   helpdlg( StringCell, 'Initial condition' );
%   figure( ud.Handle.targetfig );
%end;
%
%tspan = [ t0 tf ];
%
%% (Too late!) test of yp
%try
%   feval( yp, t0, y0 );
%   feval( yp, tf, y0 );
%catch
%   errordlg( 'Parameters and initial conditions must be assigned numeric values.', 'Error' );
%end;
%
%% Apply numerical method - add a stop check
%if isempty( ud.method )
%   warndlg( 'No method selected. Using ode45 by default.', 'Warning' );
%   [t, y] = ode45( yp, tspan, y0 );
%else
%   step = str2num( ud.deltat );
%   switch char( ud.method )
%   case 'Euler'
%      [t, y] = leuler( yp, tspan, y0, step );
%   case 'Heun'
%      [t, y] = lheun( yp, tspan, y0, step );
%   case 'RK4'
%      [t, y] = lrk4( yp, tspan, y0, step );
%   case 'ode13'
%      [t, y] = ode13( yp, tspan, y0 );
%   case 'ode45'
%      options = odeset( 'Refine', 1 );
%      [t, y] = ode45( yp, tspan, y0, options );
%   case 'ode113'
%      [t, y] = ode113( yp, tspan, y0 );
%   case 'ode13s'
%      [t, y] = ode13s( yp, tspan, y0 );
%   case 'ode15s'
%      [t, y] = ode15s( yp, tspan, y0 );
%   otherwise
%      errordlg( 'Undefined numerical method.', 'Error' );
%      set( ud.Handle.numcntrl, 'Pointer', 'arrow' );
%      return;
%   end;
%end;
%
%% Plot approximate solution
%happrox1 = feval ( 'plot', t, y(:,1), 'or' );
%harray = [ happrox1 ];
%legendtext{1} = [ char( ud.y{1} ) ' - ' char( ud.method ) ' approx.' ];
%
%if ~ishold
%   hold on;
%end;
%
%[numsteps m] = size( t );
%numsteps = numsteps - 1;
%if numsteps <= 50
%   % Connect approx solution pts with line
%   happrox2 = feval ( 'plot', t, y(:,1), ':g' );
%end;
%
%% Solution plot title
%s = prettytitle( fstring );
%title( [ 'd' char( ud.y{1} ) '/d' char( ud.t ) ' = ' s ] );
%xlabel( char( ud.t ) );
%ylabel( [ 'Approximate solution ' char( ud.y{1} ) ] );
%
%% High accuracy solution, if requested
%if get( ud.Handle.high_check, 'Value' ) == 1
%   [t, y] = ode45( yp, tspan, y0 );
%   hexact = plot( t, y, 'b' );
%   harray = [ harray hexact ];
%   legendtext{2} = [ char( ud.y{1} ) ' - High accuracy' ];
%end;
%
%legend( harray, char( legendtext ) );
%
%% (Re)plot direction field here if requested because axes changed or
%% because it was never plotted.
%if get( ud.Handle.dfield_check, 'Value' ) == 1
%   a = axis;
%   ymin = a(1, 3);
%   ymax = a(1, 4);
%
%   % If don't already need new axes from before solution plot, check
%   % to see if axes changed.
%   if NewDfldAxis == 0 & ( ymin ~= yminold | ymax ~= ymaxold )
%      NewDfldAxis = 1;
%   end;
%
%   if NewDfldAxis == 1
%      % Hide old direction field, if present, and plot new one.
%
%      h = ud.Handle.dfld;
%      if ~isempty( h )
%         delete( h );
%%         set( ud.Handle.dfld, 'Visible', 'off' );
%      end;
%
%      ud.Handle.dfld = dfld( numsteps, [ t0 tf ymin ymax ], yp );
%   end;
%
%end;
%
%set( ud.Handle.numcntrl, 'Pointer', 'arrow' );
%
%% Update "parent" equation windows.
%set( ud.Handle.order2, 'UserData', ud );
%set( ud.Handle.numcntrl, 'UserData', ud );
%set( gcbo, 'UserData', ud );
%
%% end SolvDraw
%
%%===========================
%
%function h = dfld( numsteps, a, yp )
%
%% dfld( numsteps, a, yp ) draws direction field for y' = yp on axes
%% defined by array a.  Uses min( 20, numsteps ) horizontal and
%% vertical spacing.
%
%t0 = a(1, 1);
%tf = a(1, 2);
%ymin = a(1, 3);
%ymax = a(1, 4);
%
%numpts = min( 20, numsteps );
%delt = (tf - t0)/numpts;
%dely = (ymax - ymin)/numpts;
%
%[t, y] = meshgrid( t0:delt:(tf - delt), ymin:dely:(ymax - dely) );
%grid = t + y.*sqrt(-1);
%grid = grid(:);
%t = t(:);
%y = y(:);
%[ ngridpts m ] = size( t );
%yprime = feval( yp, t, y );
%yprime = yprime(:);
%
%% Scale for varied aspect ratio
%aspect = abs( dely/delt );
%z_t = zeros(ngridpts, 1);
%z_y = zeros(ngridpts, 1);
%
%for i = 1:ngridpts
%
%   if ( abs( yprime(i) ) <= aspect )
%      z_t(i) = delt;
%      z_y(i) = delt*yprime(i);
%   else
%      z_t(i) = abs( dely/yprime(i));
%      z_y(i) = dely*sign(yprime(i));
%   end;
%
%end;
%
%z = 0.9*(z_t + z_y*sqrt(-1));
%z = z(:).';
%%theta = atan( yprime );
%%z = 0.9*(cos(theta)/abs(delt) + (sin(theta).*sqrt(-1))/abs(dely)).';
%dash = [0 1].';
%a = dash*z + ones(2,1)*grid.';
%h = plot ( real(a), imag(a), '-y' );
%set( h, 'Color', [ .75 .75 .75 ] );
%
%% end dfld

%=========================== Following copied from f_order1

function solution = dsolve2cell( s )

% Converts output of dsolve or solve to cell vector of symbols.

% dsolve can return a scalar expression of class sym, as from
% dsolve( 'Dy = y' ), an array of class sym, as from dsolve( 'Dy =
% (2/3)*y^(1/3)' ) (which has two solutions), or a structure, as
% from dsolve( 'Dy = z, Dz = -y' ).  I want the output of dsolve to
% end up as a cell vector of symbols.

sclass = class( s );

switch sclass
case 'sym'
   len = length( s );
   if len == 1
      solution{1} = s;
   else
      solution = cell(len, 1);

      for i = 1:len
         solution{i} = s(i);
      end

      solution = solution(:);
   end

case 'struct'
   names = fieldnames( s );

   len = length( names )
   solution = cell(len, 1);
   for i = 1:len
      solution{i} = getfield( s, names{i} );
   end

   solution = solution(:);

otherwise
   warndlg( 'dsolve returned other than a sym or a struct.',...
      'Warning' );
   return;
end

% end dsolve2cell
