function [tout, yout] = leuler( yp, tspan, y0, h )

% leuler( yp, tspan, y0, deltat ) solves y' = yp using Euler
% with step h.
% yp, tspan, y0 are as usual in Matlab ODE syntax, tho' tspan is
% assumed to [ t0 tfinal ] since output is spaced at deltat.
% deltat = step size.

[m n] = size( tspan );
t = tspan(1, 1);
tfinal = tspan(m, n);

y = y0(:);
tout = t;
yout = y.';

while (t < tfinal)
   if t + h > tfinal, h = tfinal - t; end

   % Compute the slope
   s = feval( yp, t, y );
   s = s(:);  % to make s a column vector

   % Update
   t = t + h;
   y = y + h*s;
   tout = [tout; t];
   yout = [yout; y.'];

end;   % while

% end leuler
