function [tout, yout] = lheun( yp, tspan, y0, h )

% lheun( yp, tspan, y0, deltat ) solves y' = yp using Heun
% with step h.
% yp, tspan, y0 are as usual in Matlab ODE syntax, tho' tspan is
% assumed to [ t0 tfinal ] since output is spaced at deltat.
% deltat = step size.

[m n] = size( tspan );
t = tspan(1, 1);
tfinal = tspan(m, n);

y = y0(:);
tout = t;
yout = y.';

while (t < tfinal)
   if t + h > tfinal, h = tfinal - t; end

   % Compute the slope
   s1 = feval(yp, t, y); s1 = s1(:);
   s2 = feval(yp, t + h, y + h*s1); s2 = s2(:);

   % Update
   t = t + h;
   n = n + 1;
   y = y + h*(s1 + s2)/2;
   tout = [tout; t];
   yout = [yout; y.'];

end;   % while

% end lheun
