function order1list

% Creates the default list of order 1 scalar equations for DELab.
% This list is the indexed structure defaultlist{i}, and it is stored
% in o1list.mat.

% All entries are strings or cells of strings, except numeqn
% (number of equations in the system)and nump (number of parameter
% boxes open in the corresponding equation window).

defaultlist{1}.id = 'Logistic';
defaultlist{1}.y = { 'P' };
defaultlist{1}.numeqn = 1;
defaultlist{1}.t = 't';
defaultlist{1}.f = { 'a*P - s*P^2' };
defaultlist{1}.pname = { 'a';  's' };
defaultlist{1}.pvalue = { '0.12';  '0.024' };
defaultlist{1}.nump = length( defaultlist{1}.pname );
defaultlist{1}.t0 = '0';
defaultlist{1}.y0 = { '1' };
defaultlist{1}.tf = '100';
defaultlist{1}.deltat = '20';
defaultlist{1}.NumStep = '5';
defaultlist{1}.ymin = '0';
defaultlist{1}.ymax = '10';
defaultlist{1}.method = 'RK4';

defaultlist{2}.id = 'Simple population';
defaultlist{2}.y = { 'P' };
defaultlist{2}.t = 't';
defaultlist{2}.f = { 'k*P' };
defaultlist{2}.pname = { 'k' };
defaultlist{2}.pvalue = { '0.0102' };
defaultlist{2}.nump = length( defaultlist{2}.pname );
defaultlist{2}.t0 = '1970';
defaultlist{2}.y0 = { '205.05' };
defaultlist{2}.tf = '2070';
defaultlist{2}.deltat = '5';
defaultlist{2}.NumStep = '20';
defaultlist{2}.ymin = '200';
defaultlist{2}.ymax = '600';
defaultlist{2}.method = 'Euler';

defaultlist{3}.id = 'Emigration';
defaultlist{3}.y = { 'P' };
defaultlist{3}.t = 't';
defaultlist{3}.f = { 'k*P - E' };
defaultlist{3}.pname = { 'k';  'E' };
defaultlist{3}.pvalue = { '0.015';  '0.209' };
defaultlist{3}.nump = length( defaultlist{3}.pname );
defaultlist{3}.t0 = '1847';
defaultlist{3}.y0 = { '8' };
defaultlist{3}.tf = '1947';
defaultlist{3}.deltat = '10';
defaultlist{3}.NumStep = '10';
defaultlist{3}.ymin = '0';
defaultlist{3}.ymax = '20';
defaultlist{3}.method = 'Euler';

defaultlist{4}.id = 'Heat loss';
defaultlist{4}.y = { 'T' };
defaultlist{4}.t = 't';
defaultlist{4}.f = { '-(A*k/c*m)*(T - Tout)' };
defaultlist{4}.pname = { 'A';  'k';  'c';  'm';  'Tout'};
defaultlist{4}.pvalue = { '0.012';  '1';  '1';  '1';  '5' };
defaultlist{4}.nump = length( defaultlist{4}.pname );
defaultlist{4}.t0 = '0';
defaultlist{4}.y0 = { '20' };
defaultlist{4}.tf = '360';
defaultlist{4}.deltat = '20';
defaultlist{4}.NumStep = '18';
defaultlist{4}.ymin = '0';
defaultlist{4}.ymax = '20';
defaultlist{4}.method = 'Euler';

defaultlist{5}.id = 'Nolan Ryan';
defaultlist{5}.y = { 'v' };
defaultlist{5}.t = 't';
defaultlist{5}.f = { '-g' };
defaultlist{5}.pname = { 'g' };
defaultlist{5}.pvalue = { '9.8' };
defaultlist{5}.nump = length( defaultlist{5}.pname );
defaultlist{5}.t0 = '0';
defaultlist{5}.y0 = { '45.1' };
defaultlist{5}.tf = '10';
defaultlist{5}.deltat = '0.5';
defaultlist{5}.NumStep = '20';
defaultlist{5}.ymin = '-50';
defaultlist{5}.ymax = '50';
defaultlist{5}.method = 'Euler';

i = 6;
defaultlist{i}.id = 'Rock model';
defaultlist{i}.y = { 'v' };
defaultlist{i}.t = 't';
defaultlist{i}.f = { '- g' };
defaultlist{i}.pname = { 'g' };
defaultlist{i}.pvalue = { '9.8' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '45.1' };
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '0.5';
defaultlist{i}.NumStep = '20';
defaultlist{i}.ymin = '-50';
defaultlist{i}.ymax = '50';
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'Rock with air resistance';
defaultlist{i}.y = { 'v' };
defaultlist{i}.t = 't';
defaultlist{i}.f = { '-(k/m)*v - g' };
defaultlist{i}.pname = { 'k';  'm';  'g'};
defaultlist{i}.pvalue = { '0.1';  '0.25';  '9.8' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '45.1' };
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '0.5';
defaultlist{i}.NumStep = '20';
defaultlist{i}.ymin = '-50';
defaultlist{i}.ymax = '50';
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'RC circuit';
defaultlist{i}.y = { 'q' };
defaultlist{i}.t = 't';
defaultlist{i}.f = { '-q/(R*C)' };
defaultlist{i}.pname = { 'R'; 'C' };
defaultlist{i}.pvalue = { '';  '' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '1' };
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '0.05';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '1';
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'Multiple solutions 1';
defaultlist{i}.y = { 'y' };
defaultlist{i}.t = 't';
defaultlist{i}.f = { '(3/2)*y^(1/3)' };
defaultlist{i}.pname = { };
defaultlist{i}.pvalue = { };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '0' };
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '1';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '-10';
defaultlist{i}.ymax = '10';
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Multiple solutions 2';
defaultlist{i}.y = { 'y' };
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'sqrt(1 - y^2)' };
defaultlist{i}.pname = { };
defaultlist{i}.pvalue = { };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '1' };
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '1';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '-10';
defaultlist{i}.ymax = '10';
defaultlist{i}.method = 'RK4';

%save d:\matlab5\toolbox\matlab\delab_dev\o1list.mat defaultlist;

% To access defaultlist, use
% load( 'd:\matlab5\toolbox\matlab\delab_dev\o1list.mat' )

directory = pwd;

if isunix
   savefile = [ directory '/o1list.mat' ];
else
   savefile = [ directory '\o1list.mat' ];
end  % if

save( savefile, 'defaultlist' )
fprintf( 'The default list of first-order equations\nhas been written to %s\n', savefile );

% end  order1list.m
