function order1sys2list

% Creates the default list of order 1 systems of 2 equations for
% DELab. This list is the indexed structure defaultlist{i}, and it
% is stored in o1sys2list.mat.

% All entries are strings or cells of strings, except numeqn
% (number of equations in the system)and nump (number of parameter
% boxes open in the corresponding equation window).

i = 1;
defaultlist{i}.id = 'Linear, homogeneous, const-coeff';
defaultlist{i}.y = { 'y'; 'z' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'a*y + b*z'; 'c*y + d*z' };
defaultlist{i}.pname = { 'a'; 'b'; 'c'; 'd' };
defaultlist{i}.pvalue = { '0'; '1'; '16'; '0' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '-1' }';
defaultlist{i}.tf = '2';
defaultlist{i}.deltat = '0.25';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = {'-2'; '-2'};
defaultlist{i}.ymax = {'2'; '2'};
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Linear - saddle point';
defaultlist{i}.y = { 'y'; 'z' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'a*y + b*z'; 'c*y + d*z' };
defaultlist{i}.pname = { 'a'; 'b'; 'c'; 'd' };
defaultlist{i}.pvalue = { '-1/2'; '3/2'; '3/2'; '-1/2' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '-1' }';
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '0.25';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = {'-2'; '-2'};
defaultlist{i}.ymax = {'2'; '2'};
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Linear - stable node';
defaultlist{i}.y = { 'y'; 'z' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'a*y + b*z'; 'c*y + d*z' };
defaultlist{i}.pname = { 'a'; 'b'; 'c'; 'd' };
defaultlist{i}.pvalue = { '-5'; '-3'; '-3'; '-5' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '-1' }';
defaultlist{i}.tf = '2';
defaultlist{i}.deltat = '0.25';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = {'-2'; '-2'};
defaultlist{i}.ymax = {'2'; '2'};
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Linear - stable spiral';
defaultlist{i}.y = { 'y'; 'z' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'a*y + b*z'; 'c*y + d*z' };
defaultlist{i}.pname = { 'a'; 'b'; 'c'; 'd' };
defaultlist{i}.pvalue = { '0'; '1'; '-1'; '-1' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '-1' }';
defaultlist{i}.tf = '2';
defaultlist{i}.deltat = '0.25';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = {'-2'; '-2'};
defaultlist{i}.ymax = {'2'; '2'};
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Nolan Ryan height, velocity';
defaultlist{i}.y = { 'y'; 'v' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'v'; '-g' };
defaultlist{i}.pname = { 'g' };
defaultlist{i}.pvalue = { '9.8' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '2.5'; '45.1' }';
defaultlist{i}.tf = '6';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '0'; '-50' };
defaultlist{i}.ymax = { '120'; '45.1' };
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'Predator-prey';
defaultlist{i}.y = { 'F'; 'R' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { '-(d_F - alpha*R)*F'; '(b_R - beta*F)*R' };
defaultlist{i}.pname = { 'd_F'; 'alpha'; 'b_R'; 'beta' };
defaultlist{i}.pvalue = { '0.04'; '0.0011'; '0.06'; '0.0009' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '60'; '40' }';
defaultlist{i}.tf = '200';
defaultlist{i}.deltat = '1';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '0'; '0'};
defaultlist{i}.ymax = { '120'; '80'};
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'SIR';
defaultlist{i}.y = { 'S' 'I' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { '-b*I*S'; 'b*I*S - r*I' };
defaultlist{i}.pname = { 'b'; 'r' };
defaultlist{i}.pvalue = { '.02'; '1' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '100'; '70' }';
defaultlist{i}.tf = '50';
defaultlist{i}.deltat = '1';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '0'; '0' };
defaultlist{i}.ymax = { '200', '200' };
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'SIRS';
defaultlist{i}.y = { 'S'; 'I' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { '-b*I*S + g*(P - S - I)'; 'b*I*S - r*I' };
defaultlist{i}.pname = { 'b'; 'r'; 'P'; 'g' };
defaultlist{i}.pvalue = { '.02'; '1'; '200'; '0.1' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '100'; '70' }';
defaultlist{i}.tf = '50';
defaultlist{i}.deltat = '1';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '0'; '0' };
defaultlist{i}.ymax = { '200', '200' };
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'Competition';
defaultlist{i}.y = { 'y'; 'z' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'y*(1 - y - e*z)'; 'r*z*(1 - z - f*y)' };
defaultlist{i}.pname = { 'e'; 'r'; 'f' };
defaultlist{i}.pvalue = { '2'; '1'; '2' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '0.32'; '0.30' }';
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '0'; '0' };
defaultlist{i}.ymax = { '1'; '1' };
defaultlist{i}.method = 'Euler';

i = i + 1;
defaultlist{i}.id = 'Spring-mass';
defaultlist{i}.y = { 'x'; 'v' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'v'; '-(k/m)*x - (p/m)*v' };
defaultlist{i}.pname = { 'm'; 'k'; 'p' };
defaultlist{i}.pvalue = { '1'; '0.25'; '0.01' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '2'; '0' }';
defaultlist{i}.tf = '12';
defaultlist{i}.deltat = '0.25';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '-2'; '-1' };
defaultlist{i}.ymax = { '2'; '1' };
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Forced spring-mass';
defaultlist{i}.y = { 'x'; 'v' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'v'; '-(k/m)*x - (p/m)*v + F*sin(omega*t)' };
defaultlist{i}.pname = { 'm'; 'k'; 'p'; 'F'; 'omega' };
defaultlist{i}.pvalue = { '1'; '0.25'; '0'; '4'; '1' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '2'; '0' }';
defaultlist{i}.tf = '6';
defaultlist{i}.deltat = '0.25';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '-2'; '-1' };
defaultlist{i}.ymax = { '2'; '1' };
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Linear pendulum - damped';
defaultlist{i}.y = { 'theta'; 'omega' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'omega'; '-(g/L)*theta - (p/L)*omega' };
defaultlist{i}.pname = { 'L'; 'g'; 'p' };
defaultlist{i}.pvalue = { '0.99295'; '9.8'; '0' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '1'; '0' };
defaultlist{i}.tf = '8';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '-7'; '-5' };
defaultlist{i}.ymax = { '7'; '5' };
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Nonlinear pendulum - damped';
defaultlist{i}.y = { 'theta'; 'omega' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { 'omega'; '-(g/L)*sin(theta) - (p/L)*omega' };
defaultlist{i}.pname = { 'L'; 'g'; 'p' };
defaultlist{i}.pvalue = { '0.99295'; '9.8'; '0' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '1'; '0' };
defaultlist{i}.tf = '8';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '-7'; '-5' };
defaultlist{i}.ymax = { '7'; '5' };
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'van der Pol';
defaultlist{i}.y = { 'I'; 'Q' };
defaultlist{i}.numeqn = 2;
defaultlist{i}.t = 't';
defaultlist{i}.f = { '-(epsilon/L)*(I^2/3 - 1)*I - Q/(L*C)'; 'I' };
defaultlist{i}.pname = { 'L'; 'epsilon'; 'C' };
defaultlist{i}.pvalue = { '1'; '5'; '1' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '2'; '0' };
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '0.05';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = { '-3'; '-5' };
defaultlist{i}.ymax = { '3'; '5' };
defaultlist{i}.method = 'RK4';

%save d:\matlab11\toolbox\matlab\delab_dev\o1sys2list.mat defaultlist;

% To access defaultlist, use
% load( 'd:\matlab5\toolbox\matlab\delab_dev\o1sys2list.mat' )

directory = pwd;

if isunix
   savefile = [ directory '/o1sys2list.mat' ];
else
   savefile = [ directory '\o1sys2list.mat' ];
end  % if

save( savefile, 'defaultlist' )
fprintf( 'The default list of first-order systems of two equations\nhas been written to %s\n', savefile );

% end  order1sys2list.m
