function order2list

% Creates the default list of order 2 scalar equations for DELab.
% This list is the indexed structure defaultlist{i}, and it is stored
% in o2list.mat.

% All entries are strings or cells of strings, except numeqn
% (number of equations in the system)and nump (number of parameter
% boxes open in the corresponding equation window).

i = 1;
defaultlist{i}.id = 'Linear, homogeneous, const-coeff';
defaultlist{i}.y = { 'y' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(b_1/b_2)*y'' - (b_0/b_2)*y' };
defaultlist{i}.pname = { 'b_2'; 'b_1'; 'b_0' };
defaultlist{i}.pvalue = { '1'; '1'; '12' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '0' };
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '2';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '10';
defaultlist{i}.method = 'ode45';

i = i + 1;
defaultlist{i}.id = 'Spring-mass';
defaultlist{i}.y = { 'x' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(p/m)*x'' - (k/m)*x' };
defaultlist{i}.pname = { 'm'; 'p'; 'k' };
defaultlist{i}.pvalue = { '.3'; '.1'; '26' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '0' };
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '2';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '10';
defaultlist{i}.method = 'ode45';

i = i + 1;
defaultlist{i}.id = 'Forced spring-mass';
defaultlist{i}.y = { 'x' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(p/m)*x'' - (k/m)*x + A*sin(omega*t)' };
defaultlist{i}.pname = { 'm'; 'p'; 'k'; 'A'; 'omega' };
defaultlist{i}.pvalue = { '.3'; '.1'; '26'; '2'; '9.3' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '0' };
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '2';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '10';
defaultlist{i}.method = 'ode45';

i = i + 1;
defaultlist{i}.id = 'Linear pendulum';
defaultlist{i}.y = { 'theta' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(g/L)*theta' };
defaultlist{i}.pname = { 'L'; 'g' };
defaultlist{i}.pvalue = { '0.99295'; '9.8' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '0' };
defaultlist{i}.tf = '8';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '.3';
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Nonlinear pendulum';
defaultlist{i}.y = { 'theta' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(g/L)*sin(theta)' };
defaultlist{i}.pname = { 'L'; 'g' };
defaultlist{i}.pvalue = { '0.99295'; '9.8' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '.1'; '0' };
defaultlist{i}.tf = '8';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '.3';
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'RLC - charge';
defaultlist{i}.y = { 'q' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(R/L)*q'' + q/(L*C)' };
defaultlist{i}.pname = { 'R'; 'L'; 'C' };
defaultlist{i}.pvalue = { ''; ''; '' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '1'; '0' };
defaultlist{i}.tf = '10';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '0';
defaultlist{i}.ymax = '1';
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'van der Pol';
defaultlist{i}.y = { 'I' };
defaultlist{i}.t = 't';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(epsilon/L)*(I^2 - 1)*I'' - I/(L*C)' };
defaultlist{i}.pname = { 'L'; 'epsilon'; 'C' };
defaultlist{i}.pvalue = { '1'; '0.1'; '1' };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '0';
defaultlist{i}.y0 = { '2'; '0' };
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '-3';
defaultlist{i}.ymax = '3';
defaultlist{i}.method = 'RK4';

i = i + 1;
defaultlist{i}.id = 'Cauchy-Euler example';
defaultlist{i}.y = { 'y' };
defaultlist{i}.t = 'x';
defaultlist{i}.numeqn = 1;
defaultlist{i}.f = { '-(3/x)*y'' + (3/x^2)*y' };
defaultlist{i}.pname = {  };
defaultlist{i}.pvalue = {  };
defaultlist{i}.nump = length( defaultlist{i}.pname );
defaultlist{i}.t0 = '1';
defaultlist{i}.y0 = { '2'; '0' };
defaultlist{i}.tf = '20';
defaultlist{i}.deltat = '0.5';
t0 = str2num( defaultlist{i}.t0 );
tf = str2num( defaultlist{i}.tf );
deltat = str2num( defaultlist{i}.deltat );
defaultlist{i}.NumStep = num2str( ceil( abs( tf - t0 )/deltat ) );
defaultlist{i}.ymin = '-3';
defaultlist{i}.ymax = '3';
defaultlist{i}.method = 'RK4';

% save d:\matlab5\toolbox\matlab\delab_dev\o2list.mat defaultlist;

% To access defaultlist, use
% load( 'd:\matlab5\toolbox\matlab\delab_dev\o2list.mat' )

directory = pwd;

if isunix
   savefile = [ directory '/o2list.mat' ];
else
   savefile = [ directory '\o2list.mat' ];
end  % if

savefile = [ directory '\o2list.mat' ];
save( savefile, 'defaultlist' )
fprintf( 'The default list of second-order equations\nhas been written to %s\n', savefile );

% end  order2list.m
