function fig = w_delab()

% Draws main window for DELab.

% Copyright 1999 Paul Davis.
% For nonprofit educational use only

load w_delab;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

%boxstring = ...
%   { 'To work with differential equations, choose Equation,';
%     'then select 1st-order, 2nd-order, or System.' };

boxstring = ...
   { 'To work with differential equations, choose Equation.';
     'Otherwise, choose Analytic, Numerical, or Graphical tools';
     'from the menu bar.' };

boxheight = 3;
boxwidth = ...
   length( [ 'Otherwise, choose an Analytic, Numerical, or Graphical Tool' ] ) + 4;

buttonstring = 'Quit';
buttonwidth = length( buttonstring ) + 4;

%figheight = (2 + 0.7 + boxheight + 2*vmargin + buttonheight);
figheight = menuheight + vmargin + boxheight + vmargin;
figwidth = max( boxwidth + 2*indent, 5*15 );

x0 = left + 0.05*width;
y0 = bottom + 0.9*height - figheight;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name','DE Lab', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight], ...
    'Tag','Fig1');
h1 = uimenu('Parent',h0, ...
    'Label','Equation' );
h2 = uimenu('Parent',h1, ...
    'Callback','f_order1( ''initialize_scalar'', ''1'' )', ...
    'Label','1st-order' );
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2( ''initialize'', ''2'' )', ...
    'Label','2nd-order' );
h2 = uimenu('Parent',h1, ...
    'Label','System' );
h3 = uimenu('Parent',h2, ...
    'Callback','f_order1( ''initialize_sys2'', ''10'' )', ...
    'Label','2 equations' );
h3 = uimenu('Parent',h2, ...
    'Callback','f_order1( ''initialize_sysN'', ''2'' )', ...
    'Label','More than 2 eqns' );

h1 = uimenu('Parent',h0, ...
    'Label','Analytic tools' );
h2 = uimenu('Parent',h1, ...
    'Callback','delab AnlEvalue', ...
    'Label','Matrix eigenvalues' );

h1 = uimenu('Parent',h0, ...
    'Label','Numerical tools' );
h2 = uimenu('Parent',h1, ...
    'Callback','delab NumEvalue', ...
    'Label','Matrix eigenvalues' );

h1 = uimenu('Parent',h0, ...
    'Label','Graphical tools' );
h2 = uimenu('Parent',h1, ...
    'Callback','delab eigshow', ...
    'Label','Eigshow' );

% web(['file:///' which('chap2.html')])
h1 = uimenu('Parent',h0, ...
    'Label','Help' );
%   callstring = ...
%      [ 'w = web([''file:///'' which(''contents.html'')]);'...
%      'if w ~= 0 helpwin contents; end' ];
%   h2 = uimenu('Parent',h1, ...
%    'Callback',callstring, ...
%    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );


xstart = figwidth - buttonwidth - hmargin;
ystart = vmargin;

h1 = uicontrol('Parent',h0, ...
    'Callback','delab quit', ...
    'ListboxTop',0, ...
    'Units', 'character', ...
    'Position',[xstart ystart buttonwidth buttonheight],...
    'String',buttonstring, ...
    'TooltipString','Quit DE Lab' );

%xstart = hmargin;
xstart = (figwidth - boxwidth)/2;
ystart = ystart + buttonheight + vmargin;

h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'ListboxTop',0, ...
    'Units', 'character', ...
    'Position',[xstart ystart boxwidth boxheight], ...
    'HorizontalAlignment','center', ...
    'String',boxstring,...
    'Style','text' );

if nargout > 0, fig = h0; end
