function fig = w_dfield( ud )

% Direction field for scalar 1st order for DELab

%load w_numcntrl
load w_delab

% Initialize local UserData
pud.tf = ud.tf;
pud.deltat = ud.deltat;
pud.NumStep = ud.NumStep;
pud.ymin = ud.ymin;
pud.ymax = ud.ymax;
pud.method = ud.method;
%pud.numpts = 20;
%pud.style = 'lines';
pud.Handle.NumStep_box = -1;  %dummy for compatibility with NumIVP
pud.targetfig = ' ';
pud.Handle.targetfig = -1;
pud.Handle.order1 = ud.Handle.order1;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

radiobuttonheight = 1.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
radiodelta = (radiobuttonheight - textboxheight)/2;
eqnboxwidth = 50;

hline = '________________________________________';
hlinewidth = 2 + length( hline );

figwidth = 2*indent + 70;
figheight = menuheight + 6.5*(vmargin + varboxheight) + vmargin;

x0 = left  + 0.99*width - figwidth;
y0 = bottom + 0.05*height;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name','Direction field', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );

h1 = uimenu('Parent',h0, ...
    'Label','Phaseline' );
    pud.Handle.show_phaseline = uimenu('Parent',h1, ...
        'Callback', 'f_order1 show_phaseline',...
        'Label', 'Show' );
    pud.Handle.hide_phaseline = uimenu('Parent',h1, ...
        'Callback', 'f_order1 hide_phaseline',...
        'Label', 'Hide' );

h1 = uimenu('Parent',h0, ...
    'Label','Options' );
   h2 = uimenu('Parent',h1, ...
       'Label','Solver' );
      % 4 is ode23, 5 is ode45, 6 is ode113, 7 is ode23s, 8 is ode15s
      pud.Handle.ode23 = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 4', ...
          'Label','Runge-Kutta 2/3 (ode23)' );
      pud.Handle.ode45 = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 5', ...
          'Label','Runge-Kutta 4/5 (ode45)' );
      pud.Handle.ode113 = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 6', ...
          'Label','Variable order (ode113)' );
      pud.Handle.ode23s = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 7', ...
          'Label','Low order stiff (ode23s)' );
      pud.Handle.ode15s = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 8', ...
          'Label','Variable order stiff (ode15s)' );
%   h2 = uimenu('Parent',h1, ...
%       'Label','Direction' );
%      pud.Handle.forward = uimenu('Parent',h2, ...
%          'Callback','f_order1 SolveForward', ...
%          'Label', [ 'Forward in ' char( ud.t ) ] );
%      pud.Handle.backward = uimenu('Parent',h2, ...
%          'Callback','f_order1 SolveBackward', ...
%          'Label', [ 'Backward in ' char( ud.t ) ] );
%      pud.Handle.both = uimenu('Parent',h2, ...
%          'Callback','f_order1 SolveForandBack', ...
%          'Label', 'Forward and backward' );
%   h2 = uimenu('Parent',h1, ...
%       'Callback', 'f_order1 tfdialog',...
%       'Label', [ 'Last ' char( ud.t ) ] );
   h2 = uimenu('Parent',h1, ...
       'Label', 'Flow lines' );
      h3 = uimenu('Parent',h2, ...
          'Callback', 'f_order1 numpts',...
          'Label', 'Number' );
      h3 = uimenu('Parent',h2, ...
          'Label', 'Style' );
         pud.Handle.lines = uimenu('Parent',h3, ...
             'Callback', 'f_order1 lines',...
             'Label', 'Lines' );
         pud.Handle.arrows = uimenu('Parent',h3, ...
             'Callback', 'f_order1 arrows',...
             'Label', 'Arrows' );

%   h2 = uimenu('Parent',h1, ...
%       'Callback', 'f_order1 numpts',...
%       'Label', 'Grid size' );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin graphical', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

%% Stop at ...
%x = hmargin + indent;
%y = figheight - menuheight;
%%y = y + delta;
%text = ...
%   [ 'Stop at ' char( ud.t ) ' =' ];
%textwidth = 2 + length( text );
%uicontrol('Parent',h0, ...
%    'BackgroundColor',[0.8 0.8 0.8], ...
%    'Units', 'character', ...
%    'Position',[ x y textwidth textboxheight ], ...
%    'String',text, ...
%    'Style','text' );
%x = x + textwidth;
%y = y - delta;
%pud.Handle.tf_box = uicontrol('Parent',h0, ...
%    'BackgroundColor',[1 1 1], ...
%    'Callback','f_order1 tf_edit', ...
%    'ListboxTop',0, ...
%    'Units', 'character', ...
%    'Position',[ x y varboxwidth varboxheight ], ...
%    'String',char( pud.tf ), ...
%    'Style','edit' );
%
% Display options
x = hmargin + indent;
y = figheight - menuheight;
text = 'Display options';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = hmargin + 2*indent;
y = y - textboxheight - vmargin;
text = 'Plot on';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'new figure';
textwidth = 7 + length( text );
pud.Handle.NewFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 NewFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'figure no.';
textwidth = 5 + length( text );
pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 CurrentFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );
x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.figure_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 targetfig_edit', ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.targetfig ), ...
    'Style','edit' );

%x = x + 2*hmargin + textwidth;
%text = 'previous figure';
%textwidth = 7 + length( text );
%pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
%    'BackgroundColor',[0.8 0.8 0.8], ...
%    'Units', 'character', ...
%    'Callback','f_order1 CurrentFig_radio', ...
%    'Position',[ x y textwidth radiobuttonheight ],...
%    'String',text, ...
%    'Style','radiobutton', ...
%    'Min',0,'Max',1 );
%
x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = [ 'Min ' char( ud.t ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
%y = y - delta;
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y varboxwidth  textboxheight ], ...
    'String',char( ud.t0 ), ...
    'Style','text' );

x = x + 2*hmargin + varboxwidth;
%y = y + delta;
text = [ 'Max ' char( ud.t ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.tf_box = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 tf_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( ud.ymax ), ...
    'Style','edit' );

x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = [ 'Min ' char( ud.y ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.ymin_box  = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback', 'f_order1 ymin_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( pud.ymin ), ...
    'Style','edit' );

x = x + 2*hmargin + varboxwidth;
y = y + delta;
text = [ 'Max ' char( ud.y ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.ymax_box  = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback', 'f_order1 ymax_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( ud.ymax ), ...
    'Style','edit' );

x = (figwidth - hlinewidth)/2;
y = y - textboxheight - vmargin;
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y hlinewidth textboxheight ], ...
    'String',hline, ...
    'Style','text' );

%Initial value
x = hmargin + indent;
y = y - varboxheight - vmargin;
text = 'Initial value';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'Use entered value';
textwidth = 7 + length( text );
pud.Handle.UseEnteredIC_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 UseEnteredIC_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'Click on figure';
textwidth = 7 + length( text );
pud.Handle.ClickIC_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 ClickIC_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

% Buttons across bottom
x = hmargin + indent;
y = y - 3*vmargin - varboxheight;
buttonstring = 'Start';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 Startdfield', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Plot', ...
    'ToolTipString','Plot direction field' );
    %'Execute one step of method' );

x = x + hmargin + buttonwidth;
y = y + delta;
text = 'Now click on figure';
textwidth = length( text ) + 4;
pud.Handle.ClickText = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'ForegroundColor', [ 1 0 0 ], ...
    'HorizontalAlignment', 'left', ...
    'Position',[x  y  textwidth    textboxheight], ...
    'Visible', 'off', ...
    'String',text, ...
    'Style','text' );

x = figwidth - buttonwidth - hmargin - indent;
y = y - delta;
buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 closepanel', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

% update "parent" equation window as well
ud.Handle.dfield = h0;
set( ud.Handle.order1, 'UserData', ud );

if nargout > 0, fig = h0; end
