function fig = w_entermatrix( n, casename )

% Enter n x n matrix

load w_delab

% Initialize local UserData
pud.entry = cell(n, n);
pud.Handle.entry = zeros(n, n);

switch casename
case 'eigshow'
   titlestring = 'Enter matrix for eigshow';
   buttonstring = 'Start eigshow';
   callstring = 'delab starteigshow';
   helpstring = 'helpwin graphical';

case 'NumEvalue'
   titlestring = 'Enter matrix for numerical e-values';
   buttonstring = 'Find eigenvalues';
   callstring = 'delab startNumEvalue';
   helpstring = 'helpwin numerical';

case 'AnlEvalue'
   titlestring = 'Enter matrix for analytic e-values';
   buttonstring = 'Find eigenvalues';
   callstring = 'delab startAnlEvalue';
   helpstring = 'helpwin analytic';

end  % case

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

radiobuttonheight = 1.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
radiodelta = (radiobuttonheight - textboxheight)/2;
eqnboxwidth = 50;

%hline = '________________________________________';
%hlinewidth = 2 + length( hline );

figwidth = 2*indent + max( [ length( titlestring ) + 12, ...
   2*(9 + hmargin) + 2*hmargin + length( buttonstring) + 4, ...
   n*(varboxwidth + hmargin)  ] );
figheight = menuheight + (n + 1)*(vmargin + varboxheight) + 2*vmargin + buttonheight;

x0 = left  + 0.05*width;
y0 = bottom + 0.5*height;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name',titlestring, ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback', helpstring, ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

x = indent + hmargin;
y = figheight - menuheight;
s = num2str( n );
text = ...
   [ 'Enter the coefficients of a ' s ' x ' s ' matrix.' ];
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

y = y - 2*vmargin;
xstart = ( figwidth - n*varboxwidth - (n - 1)*hmargin )/2;
x = xstart;

% Start brackets
xleft = x - 1;
ytop = y + 0.4;
xright = x + n*varboxwidth + (n - 1)*hmargin + 1;
haxes = axes;
set( haxes, 'Visible', 'off', 'Units', 'Characters', ...
    'Position', [ 0 0 figwidth figheight ] );
axis( [ 0 figwidth 0 figheight ] );
bw = 0.75;
lw = 1;
line( [ xleft; xleft + bw ], [ ytop; ytop ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );
line( [ xright - bw; xright ], [ ytop; ytop ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );

y = y - varboxheight;

for i = 1:n
   for j = 1:n
      pud.Handle.entry(i, j) = uicontrol('Parent',h0, ...
         'BackgroundColor',[1 1 1], ...
         'Units', 'character', ...
         'Position',[ x y varboxwidth varboxheight ], ...
         'String',char( pud.entry{i, j} ), ...
         'Style','edit' );
         x = x + hmargin + varboxwidth;
   end  % for j

%   x = indent + hmargin;
   x = xstart;
   y = y - vmargin - varboxheight;
end  % for i

% Finish brackets
ybottom = y + vmargin + varboxheight - 0.4;
line( [ xleft; xleft; xleft + bw ], [ ytop; ybottom; ybottom ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );
line( [ xright - bw; xright; xright ], [ ybottom; ybottom; ytop ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );
%line( [ xleft; xleft ], [ ytop; ybottom ], ...
%   'Color', [ 0 0 0 ], 'LineWidth', lw );
%line( [ xright; xright ], [ ytop; ybottom ], ...
%   'Color', [ 0 0 0 ], 'LineWidth', lw );

% Buttons across bottom
x = hmargin + indent;
y = y - 2*vmargin;
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback', callstring, ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String',buttonstring, ...
    'ToolTipString',buttonstring );

buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
x = figwidth - 2*(buttonwidth + hmargin) - indent;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x + buttonwidth + hmargin;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 close', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

% update "parent" equation window as well
% set( ud.Handle.order1, 'UserData', ud );

if nargout > 0, fig = h0; end
