function fig = w_evalue( n, A, V, D, titlestring )

% Display evalues D, evectors V of n x n matrix A, all passed as
% cell arrays of characters (from numerical eigenvalue) or symbols
% (from analytic eigenvalue) stacked columnwise.

load w_delab

pud.n = n;
pud.A = A;
pud.V = V;
pud.D = D;
pud.titlestring = titlestring;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

MyColor = [ 1 1 1 ];

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

textboxheight = 1;
MyColor = [ 1 1 1 ];

% Find width of max entry in A, V, D
Vwidth = 0;
Dwidth = 0;
Awidth = 0;
for i = 1:n
   Dwidth = max( [ Dwidth length( char( D{i} ) ) ] );
end  % for

for i = 1:(n*n)
   Vwidth = max( [ Vwidth length( char( V{i} ) ) ] );
   Awidth = max( [ Awidth length( char( A{i} ) ) ] );
end  % for

Vwidth = Vwidth + 2;
Dwidth = Dwidth + 2;
Awidth = Awidth + 2;
Mwidth = max( [ Vwidth Dwidth Awidth ] );

estring = 'has the eigenvalues and eigenvectors';
estringwidth = length( estring ) + 4;

figwidth = 2*indent + max( [ length( titlestring ) + 12, ...
   (n + 1)*Mwidth + 2*indent + 2*hmargin + 7, ...
   estringwidth + 2*(hmargin + indent), ...
   2*(9 + hmargin + indent) + hmargin  ] );
figheight = menuheight + 2*n*(vmargin + textboxheight) + 7*vmargin + buttonheight;

x0 = left  + 0.95*width - figwidth;
y0 = bottom + 0.8*height - figheight;
%y0 = bottom + 0.5*height;

h0 = figure('Color', MyColor, ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name',titlestring, ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position', [x0 y0 figwidth figheight] );

if strcmp( titlestring, 'Analytic eigenvalues' )
   helpstring = 'helpwin analytic';
   h1 = uimenu('Parent',h0, ...
       'Label','Manipulate' );
   s1 = 'pud = get( gcf, ''UserData'' );';
   s2 = 'f_evalue( ''simplify'', pud.n, pud.A, pud.V, pud.D, pud.titlestring )';
   h2 = uimenu('Parent',h1, ...
       'Label','Simplify', ...
       'Callback', [ s1 s2 ] );
   s2 = 'f_evalue( ''simple'', pud.n, pud.A, pud.V, pud.D, pud.titlestring )';
   h2 = uimenu('Parent',h1, ...
       'Label','Simple', ...
       'Callback', [ s1 s2 ] );
   s2 = 'f_evalue( ''4digits'', pud.n, pud.A, pud.V, pud.D, pud.titlestring )';
   h2 = uimenu('Parent',h1, ...
       'Label','4 digit numbers', ...
       'Callback', [ s1 s2 ] );
   s2 = 'f_evalue( ''8digits'', pud.n, pud.A, pud.V, pud.D, pud.titlestring )';
   h2 = uimenu('Parent',h1, ...
       'Label','8 digit numbers', ...
       'Callback', [ s1 s2 ] );
   %s2 = 'f_evalue( ''pretty'', pud.n, pud.A, pud.V, pud.D, pud.titlestring )';
   %h2 = uimenu('Parent',h1, ...
   %    'Label','Pretty print', ...
   %    'Callback', [ s1 s2 ] );
else
   helpstring = 'helpwin numerical';
end  % if

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback', helpstring, ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

xstart = indent + hmargin;
x = xstart;
y = figheight - menuheight;

% Start brackets
xleft = x - 1;
ytop = y + 0.4;
xright = x + n*Awidth + 1;
haxes = axes;
set( haxes, 'Visible', 'off', 'Units', 'Characters', ...
    'Position', [ 0 0 figwidth figheight ] );
axis( [ 0 figwidth 0 figheight ] );
bw = 0.75;
lw = 1;
line( [ xleft; xleft + bw ], [ ytop; ytop ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );
line( [ xright - bw; xright ], [ ytop; ytop ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );

y = y - textboxheight;

for i = 1:n
   for j = 1:n
      uicontrol('Parent',h0, ...
         'BackgroundColor', MyColor, ...
         'Units', 'character', ...
         'Position',[ x y Awidth textboxheight ], ...
         'String',char( A{i + n*(j - 1)} ), ...
         'HorizontalAlignment','center',...
         'Style','text' );
         x = x + Awidth;
   end  % for j

   x = xstart;
   y = y - vmargin - textboxheight;
end  % for i

% Finish brackets
ybottom = y + vmargin + textboxheight - 0.4;
line( [ xleft; xleft; xleft + bw ], [ ytop; ybottom; ybottom ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );
line( [ xright - bw; xright; xright ], [ ybottom; ybottom; ytop ], ...
   'Color', [ 0 0 0 ], 'LineWidth', lw );
%line( [ xleft; xleft ], [ ytop; ybottom ], ...
%   'Color', [ 0 0 0 ], 'LineWidth', lw );
%line( [ xright; xright ], [ ytop; ybottom ], ...
%   'Color', [ 0 0 0 ], 'LineWidth', lw );

% has the eigenvalues and eigenvectors
y = y - vmargin;
%x = ( figwidth - length( string ) )/2;
x = hmargin + indent;
uicontrol('Parent',h0, ...
   'BackgroundColor', MyColor, ...
   'Units', 'character', ...
   'Position',[ x y estringwidth textboxheight ], ...
   'String', estring, ...
   'HorizontalAlignment','left',...
   'Style','text' );

% eigenvalues and vectors
xstart = hmargin;
x = xstart;
y = y - textboxheight - vmargin;

for i = 1:n
   string = [ char( D{i} ) '  <=>  ( ' ];
   uicontrol('Parent',h0, ...
      'BackgroundColor', MyColor, ...
      'Units', 'character', ...
      'Position',[ x y (Dwidth + 9) textboxheight ], ...
      'String', string, ...
      'HorizontalAlignment','right',...
      'Style','text' );
   x = x + Dwidth + 9;

   for j = 1:n
      uicontrol('Parent',h0, ...
         'BackgroundColor', MyColor, ...
         'Units', 'character', ...
         'Position',[ x y Vwidth textboxheight ], ...
         'String',char( V{i + (n - 1)*j} ), ...
         'HorizontalAlignment','center',...
         'Style','text' );
      x = x + Vwidth;
   end  % for j

   uicontrol('Parent',h0, ...
      'BackgroundColor', MyColor, ...
      'Units', 'character', ...
      'Position',[ x y 6 textboxheight ], ...
      'String', ')^T', ...
      'HorizontalAlignment','left',...
      'Style','text' );

   x = xstart;
   y = y - vmargin - textboxheight;
end  % for i

% Buttons across bottom
x = hmargin + indent;
y = vmargin;
buttonstring = 'Print';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','GUIprint', ...
    'Units', 'character', ...
    'Position',[x y buttonwidth buttonheight], ...
    'String','Print', ...
    'TooltipString','Print this window' );

buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
%x = figwidth - 2*(buttonwidth + hmargin) - indent;
%h1 = uicontrol('Parent',h0, ...
%    'Callback','f_order1 quit', ...
%    'Units', 'character', ...
%    'Position',[x  y  buttonwidth    buttonheight], ...
%    'String','Quit', ...
%    'ToolTipString','Quit DE Lab' );
%
x = figwidth - hmargin - indent - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 close', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

if nargout > 0, fig = h0; end
