function fig = w_numivp( ud )

% Numerical control panel for numerical IVP methods for DELab

load w_delab
%load w_numcntrl

% Initialize local UserData
pud.tf = ud.tf;
pud.deltat = ud.deltat;
pud.NumStep = ud.NumStep;
pud.ymin = ud.ymin;
pud.ymax = ud.ymax;
pud.method = ud.method;
pud.targetfig = ' ';
pud.Handle.targetfig = -1;
pud.Handle.order1 = ud.Handle.order1;

neqn = ud.numeqn;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

radiobuttonheight = 1.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
radiodelta = (radiobuttonheight - textboxheight)/2;
eqnboxwidth = 50;

hline = '________________________________________';
hlinewidth = 2 + length( hline );

figwidth = 2*indent + 90;
figheight = menuheight + 7.5*(vmargin + varboxheight) + vmargin;

x0 = left  + 0.99*width - figwidth;
y0 = bottom + 0.05*height;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name','Numerical approximation of IVP', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin numerical', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

% Method line
x = hmargin + indent;
y = figheight - menuheight;
text = 'Method:';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );
x = x + hmargin + textwidth;
y = y - delta;
popupwidth = 7 + length( 'Adaptive: variable-order (ode113)' );
popupcell = { 'Euler'; 'Heun/RK2'; 'Runge-Kutta 4';...
   'Adaptive: Runge-Kutta 2/3'; 'Adaptive: Runge-Kutta 4/5';...
   'Adaptive: variable-order (ode113)'; 'Stiff: low-order (ode23s)';
    'Stiff: variable-order (ode15s)' };
callstring = [ 'f_order1 SetMethod get( gcbo, ''Value'' );' ];
pud.Handle.MethodPopUp = uicontrol('Parent',h0, ...
    'BackgroundColor',[ 1 1 1 ], ...
    'Units', 'character', ...
    'Position',[ x y popupwidth varboxheight ], ...
    'Callback', callstring,...
    'String', popupcell, ...
    'Style','popup' );

x = x + popupwidth + 2*hmargin;
y = y + delta;
text = ...
   [ 'Stop at ' char( ud.t ) ' =' ];
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'String',text, ...
    'Style','text' );
x = x + textwidth;
y = y - delta;
pud.Handle.tf_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 tf_edit', ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.tf ), ...
    'Style','edit' );

%% Step size
%string = char( pud.method );
%if strcmpi( 'Euler', string ) | strcmpi( 'Heun', string ) ...
%   | strcmpi( 'RK4', string )
%   visible = 'on';
%else
%   visible = 'off';
%end

x = hmargin + indent;
y = y - varboxheight - vmargin;
text = 'Choose';
textwidth = 2 + length( text );
pud.Handle.Choose_text = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + textwidth;
y = y - radiodelta;
text = 'step size';
textwidth = 7 + length( text );
pud.Handle.StepSize_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 StepSize_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.StepSize_box = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 deltat_edit', ...
    'Position',[ x y varboxwidth varboxheight ],...
    'String',char( pud.deltat ), ...
    'Style','edit' );

x = x + 2*hmargin + textwidth;
y = y + delta - radiodelta;
text = 'number of steps';
textwidth = 7 + length( text );
pud.Handle.NumStep_radio = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Callback','f_order1 NumStep_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.NumStep_box = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 NumStep_edit', ...
    'ListboxTop',0, ...
    'Position',[ x y varboxwidth varboxheight ],...
    'String',char( pud.NumStep ), ...
    'Style','edit' );

x = (figwidth - hlinewidth)/2;
y = y - textboxheight - vmargin;
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y hlinewidth textboxheight ], ...
    'String',hline, ...
    'Style','text' );

% Output options
x = hmargin + indent;
y = y - varboxheight - vmargin;
text = 'Output options';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = hmargin + 2*indent;
y = y - textboxheight - vmargin;
text = 'Graphical';
graphtextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y graphtextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + graphtextwidth;
y = y - radiodelta;
text = [ 'Plot vs. ' char( ud.t )];
textwidth = 7 + length( text );
pud.Handle.odeplot_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 odeplot', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

if neqn == 1 | neqn > 3
   pud.Handle.odephase_radio = -1;
elseif neqn == 2
   x = x + 2*hmargin + textwidth;
   text = 'Phase plane';
   textwidth = 7 + length( text );
   pud.Handle.odephase_radio = uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'Units', 'character', ...
       'Callback','f_order1 odephas2', ...
       'Position',[ x y textwidth radiobuttonheight ],...
       'String',text, ...
       'Style','radiobutton', ...
       'Min',0,'Max',1 );
elseif neqn == 3
   x = x + 2*hmargin + textwidth;
   text = 'Phase space';
   textwidth = 7 + length( text );
   pud.Handle.odephase_radio = uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'Units', 'character', ...
       'Callback','f_order1 odephas3', ...
       'Position',[ x y textwidth radiobuttonheight ],...
       'String',text, ...
       'Style','radiobutton', ...
       'Min',0,'Max',1 );
end  % if

x = x + 2*hmargin + textwidth;
text = 'None';
textwidth = 7 + length( text );
pud.Handle.nograph_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 nograph', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = hmargin + 2*indent + 2*hmargin + graphtextwidth;
y = y - textboxheight - vmargin;
text = 'Plot on';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'new figure';
textwidth = 7 + length( text );
pud.Handle.NewFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 NewFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'figure no.';
textwidth = 5 + length( text );
pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 CurrentFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );
x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.figure_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 targetfig_edit', ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.targetfig ), ...
    'Style','edit' );

x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = 'Numerical';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + graphtextwidth;
x = x + 4;  %fudge
y = y - radiodelta;
text = 'Save values in MATLAB workspace';
textwidth = 7 + length( text );
pud.Handle.workspacearray_check = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth radiobuttonheight ], ...
    'String', text,...
    'Style','checkbox', ...
    'Min',0,'Max',1 );

%    'Callback','f_order1 workspacearray', ...

% Start, etc. buttons
x = hmargin + indent;
y = y - 3*vmargin - varboxheight;
buttonstring = 'Start';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 StartNumIVP', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String',buttonstring, ...
    'ToolTipString','Start numerical approximation' );

x = figwidth - buttonwidth - hmargin - indent;
buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 closepanel', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

% update "parent" equation window as well
ud.Handle.numivp = h0;
set( ud.Handle.order1, 'UserData', ud );

if nargout > 0, fig = h0; end
