function fig = w_order1( ud )

% GUI for order 1 equations
% ud.y, ud.t, ud.f are strings describing y, t, f
% for the ODE dy/dt = f(t, y)

load w_delab;

% Default equation list
if ud.numeqn == 1
   load o1list.mat;
elseif ud.numeqn == 2
   load o1sys2list.mat;
else
   load o1sysNlist.mat;
end  % if

% pre-allocate storage for w_order1 handles;
ud.Handle.y_box = -ones(1, ud.numeqn);
ud.Handle.yparen_box = -ones(1, ud.numeqn);
ud.Handle.t_box = -ones(1, ud.numeqn);
ud.Handle.f_box = -ones(1, ud.numeqn);
ud.Handle.pname_box = -ones(1, ud.nump);
ud.Handle.pvalue_box = -ones(1, ud.nump);
ud.Handle.t0_box = -ones(1, ud.numeqn);
ud.Handle.y0_box = -ones(1, ud.numeqn);

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

x0 = left + 0.01*width;
y0 = bottom + 0.05*height;

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
eqnboxwidth = 50;

textd = 'd ';
textdwidth = length( textd ) + 2;
textdslash = '/ d';
textdslashwidth = length( textdslash ) + 2;
textequal = ' = ';
textequalwidth = length( textequal ) + 2;

figheight = menuheight ...
    + ud.numeqn*(varboxheight + vmargin) ...
    + textboxheight + 2*vmargin...
    + ceil( ud.nump/2 )*(vmargin + varboxheight) ...
    + 2*vmargin + textboxheight ...
    + ud.numeqn*(varboxheight + vmargin) ...
    + 2*vmargin + buttonheight + vmargin;
figwidth = hmargin + indent + textdwidth + varboxwidth ...
    + textdslashwidth ...
    + varboxwidth + textequalwidth + eqnboxwidth + vmargin ...
    + indent;

% Open window and build menu bar
if ud.numeqn == 1
    string = 'First-order equation';
else
    string = 'System of first-order equations';
end  % if

h0 = figure('Units','character', ...
    'Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name', string, ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );
h1 = uimenu('Parent',h0, ...
    'Label','Equation' );
h2 = uimenu('Parent',h1, ...
    'Label','From list');

    for i = 1:length(defaultlist)
       h3 = uimenu('Parent',h2, ...
           'Callback',[ 'f_order1 FromDefaultList ' num2str(i)  ], ...
           'Label',defaultlist{i}.id);
    end;

h2 = uimenu('Parent',h1, ...
    'Callback','f_order1 Save', ...
    'Label','Save to list',...
    'Enable', 'off' );
% try     'Callback','f_order1 all_edit', ... here
%alledit = [ 'f_order1( y_edit); f_order1( f_edit); ' ...
%   'f_order1( t_edit); f_order1( t0_edit); f_order1( y0_edit); '
%   'f_order1( pname_edit); f_order1( pvalue_edit);' ];

h1 = uimenu('Parent',h0, ...
    'Label','Analytic tools', ...
    'Tag','uimenu2');
%    'Callback', 'f_order1 all_edit',...
%    'Interruptible', 'off',...
h2 = uimenu('Parent',h1, ...
    'Callback','f_order1 all_edit; f_order1 AnlSolveODE', ...
    'Label','ODE solution', ...
    'Tag','Analytic tooluimenu1');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order1 AnlSolveIVP', ...
    'Label','IVP solution', ...
    'Tag','Analytic tooluimenu2');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order1 StdyState', ...
    'Label','Steady state(s)', ...
    'Tag','Analytic toolsuimenu1');
h1 = uimenu('Parent',h0, ...
    'Label','Numerical tools', ...
    'Tag','uimenu3');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order1 numivp 0', ...
    'Label','Approx. solution of IVP', ...
    'Tag','Numerical toolsuimenu1');

if ud.numeqn == 1
   h2 = uimenu('Parent',h1, ...
       'Callback','f_order1 visdemo', ...
       'Label','Visual demo''s' );
end

h1 = uimenu('Parent',h0, ...
    'Label','Graphical tools' );

if ud.numeqn == 1
   h2 = uimenu('Parent',h1, ...
       'Callback','f_order1 dfield 0', ...
       'Label','Direction field' );
   h2 = uimenu('Parent',h1, ...
       'Callback','f_order1 phaseline 0', ...
       'Label','Phase line' );
elseif ud.numeqn == 2
   h2 = uimenu('Parent',h1, ...
       'Callback','f_order1 phaseplane 0', ...
       'Label','Phase plane' );
%elseif ud.numeqn == 3
%   h2 = uimenu('Parent',h1, ...
%       'Callback','f_order1 phasespace 0', ...
%       'Label','Phase space' );
else
   h2 = uimenu('Parent',h1, ...
       'Label','Phase diagram' );
      h3 = uimenu('Parent',h2, ...
          'Callback','f_order1 phaseplane 0', ...
          'Label','2-D' );
      h3 = uimenu('Parent',h2, ...
          'Callback','f_order1 phasespace 0', ...
          'Label','3-D' );
end

if isempty( ud.t )
   text = 'ind. var.';
else
   text = char( ud.t );
end  % if

h2 = uimenu('Parent',h1, ...
    'Callback','f_order1 plotvst 0', ...
    'Label',[ 'Solution plot vs ' text ] );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin equation', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

% Equation
y = figheight - menuheight;
for i = 1:ud.numeqn
    x = hmargin + indent;
    h1 = uicontrol('Parent',h0, ...
        'BackgroundColor',[0.8 0.8 0.8], ...
        'Units', 'character', ...
        'Position',[ x y textdwidth textboxheight ], ...
        'String',textd, ...
        'Style','text' );

    x = x + textdwidth;
    y = y - delta;
    ud.Handle.y_box(i) = uicontrol('Parent',h0, ...
        'Callback','f_order1 y_edit', ...
        'BackgroundColor',[1 1 1], ...
        'ListboxTop',0, ...
        'Units', 'character', ...
        'Position',[ x y varboxwidth varboxheight ], ...
        'HorizontalAlignment','center', ...
        'String', char(ud.y{i}),...
        'Style','edit' );

    x = x + varboxwidth;
    y = y + delta;
    h1 = uicontrol('Parent',h0, ...
        'BackgroundColor',[0.8 0.8 0.8], ...
        'ListboxTop',0, ...
        'Units', 'character', ...
        'Position',[ x y textdslashwidth textboxheight ], ...
        'String',textdslash, ...
        'Style','text' );

    x = x + textdslashwidth;
    y = y - delta;
    if i == 1
        ud.Handle.t_box(1) = uicontrol('Parent',h0, ...
            'Callback','f_order1 t_edit', ...
            'BackgroundColor',[1 1 1], ...
            'Units', 'character', ...
            'Position',[ x y varboxwidth varboxheight ], ...
            'HorizontalAlignment','center', ...
            'String', char(ud.t),...
            'Style','edit' );
    else
        ud.Handle.t_box(i) = uicontrol('Parent',h0, ...
            'BackgroundColor',[0.8 0.8 0.8], ...
            'Units', 'character', ...
            'Position',[ x (y - delta) varboxwidth varboxheight ], ...
            'HorizontalAlignment','center', ...
            'String', char(ud.t),...
            'Style','text' );
    end   % if

    x = x + varboxwidth;
    y = y + delta;
    h1 = uicontrol('Parent',h0, ...
        'BackgroundColor',[0.8 0.8 0.8], ...
        'Units', 'character', ...
        'Position',[x y textequalwidth textboxheight ], ...
        'String',textequal, ...
        'Style','text' );

    x = x + textequalwidth;
    y = y - delta;
    ud.Handle.f_box(i) = uicontrol('Parent',h0, ...
        'Callback','f_order1 f_edit', ...
        'BackgroundColor',[1 1 1], ...
        'Units', 'character', ...
        'Position',[ x y eqnboxwidth varboxheight ], ...
        'HorizontalAlignment','left', ...
        'String', char(ud.f{i}),...
        'Style','edit' );

    y = y - varboxheight - vmargin;
end   % for

% Parameters
% fprintf( 'length ud.Handle.pname_box = %g\n', length( ud.Handle.pname_box ) );
% fprintf( 'length ud.Handle.pvalue_box = %g\n', length( ud.Handle.pvalue_box ) );
x = hmargin;
%y = y - vmargin - delta - textboxheight;

thisboxwidth = 10 + 4;
h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','left', ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String','Parameters', ...
    'Style','text' );

if ud.nump == 0
   x = x + thisboxwidth;
   uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','left', ...
    'Units', 'character', ...
    'Position',[ x y 9 textboxheight ], ...
    'String',' - none', ...
    'Style','text' );
end  % if


y = y - varboxheight - vmargin;
for i = 1:2:ud.nump;
   x = hmargin + indent;

   % Parameter boxes on left
   ud.Handle.pname_box(i) = uicontrol('Parent',h0, ...
       'Callback','f_order1 pname_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth  varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', char(ud.pname{i}),...
       'Style','edit' );
   x = x + varboxwidth;
   y = y + delta;
   thisboxwidth = 1 + 4;
   h1 = uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'ListboxTop',0, ...
       'Units', 'character', ...
       'Position',[ x y thisboxwidth textboxheight ], ...
       'String','=', ...
       'Style','text' );
   x = x + thisboxwidth;
   y = y - delta;
   ud.Handle.pvalue_box(i) = uicontrol('Parent',h0, ...
       'Callback','f_order1 pvalue_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', char(ud.pvalue{i}),...
       'Style','edit' );

   % Parameters boxes on right

   if i + 1 > ud.nump
       y = y - varboxheight - vmargin;
       break;
   end

   x = x + varboxwidth + 4*hmargin;
   ud.Handle.pname_box(i + 1) = uicontrol('Parent',h0, ...
       'Callback','f_order1 pname_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth  varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', char(ud.pname{i + 1}),...
       'Style','edit' );
   x = x + varboxwidth;
   y = y + delta;
   thisboxwidth = 1 + 4;
   h1 = uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'ListboxTop',0, ...
       'Units', 'character', ...
       'Position',[ x y thisboxwidth textboxheight ], ...
       'String','=', ...
       'Style','text' );
   x = x + thisboxwidth;
   y = y - delta;
   ud.Handle.pvalue_box(i + 1) = uicontrol('Parent',h0, ...
       'Callback','f_order1 pvalue_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', char(ud.pvalue{i + 1}),...
       'Style','edit' );

   y = y - varboxheight - vmargin;
end;

% Initial condition
x = hmargin;

if ud.numeqn == 1
   text = [ 'Initial condition' ];
else
   text = [ 'Initial conditions' ];
end

thisboxwidth = length( text ) + 4;
h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','left', ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String',text, ...
    'Style','text' );

y = y - vmargin - varboxheight + delta;
for i = 1:ud.numeqn
    x = hmargin + indent;
    thisboxwidth = varboxwidth + 2;
    ud.Handle.yparen_box(i) = uicontrol('Parent',h0, ...
        'BackgroundColor',[0.8 0.8 0.8], ...
        'HorizontalAlignment','right', ...
        'Units', 'character', ...
        'Position',[ x y thisboxwidth textboxheight ], ...
        'String', [ char(ud.y{i}) '( ' ], ...
        'Style','text' );

    x = x + thisboxwidth;
    y = y - delta;
    if i == 1
        ud.Handle.t0_box(1) = uicontrol('Parent',h0, ...
            'Callback','f_order1 t0_edit', ...
            'BackgroundColor',[1 1 1], ...
            'Units', 'character', ...
            'Position',[ x y varboxwidth varboxheight ], ...
            'HorizontalAlignment','center', ...
            'String', char(ud.t0),...
            'Style','edit' );
    else
        ud.Handle.t0_box(i) = uicontrol('Parent',h0, ...
            'BackgroundColor',[0.8 0.8 0.8], ...
            'Units', 'character', ...
            'Position',[ x (y - delta) varboxwidth varboxheight ], ...
            'HorizontalAlignment','center', ...
            'String', char(ud.t0),...
            'Style','text' );
    end   % if

    x = x + varboxwidth;
    y = y + delta;
    thisboxwidth = 4 + 1;
    h1 = uicontrol('Parent',h0, ...
        'BackgroundColor',[0.8 0.8 0.8], ...
        'Units', 'character', ...
        'Position',[ x y thisboxwidth textboxheight ], ...
        'String',')  =', ...
        'HorizontalAlignment','center', ...
        'Style','text' );

    x = x + thisboxwidth;
    y = y - delta;
    ud.Handle.y0_box(i) = uicontrol('Parent',h0, ...
        'Callback','f_order1 y0_edit', ...
        'BackgroundColor',[1 1 1], ...
        'Units', 'character', ...
        'Position',[ x  y   varboxwidth   varboxheight ], ...
        'HorizontalAlignment','center', ...
        'String', char(ud.y0{i}),...
        'Style','edit' );

   y = y - varboxheight - vmargin;
end   % for

% Buttons at bottom
x = hmargin;
y = vmargin;

buttonstring = 'Add parameter';
buttonwidth = length( buttonstring ) + 4;

uicontrol('Parent',h0, ...
    'Callback','f_order1 AddParameter', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String',buttonstring, ...
    'ToolTipString','Add another parameter' );

x = figwidth - buttonwidth - hmargin;

buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;

h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','close', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

ud.Handle.order1 = h0;
set( h0, 'UserData', ud );

if nargout > 0, fig = h0; end
