function fig = w_order2( ud )

% GUI for order 2 equation
% ud.y, ud.t, ud.f are strings describing y, t, f
% for the ODE d^2y/dt^2 = f(t, y, y')

load w_delab
%load w_order2

%load( 'd:\matlab5\toolbox\matlab\delab_dev\o2list.mat' )
load o2list.mat;

% Pre-allocate storage for w_order2 handles.
ud.Handle.y_box = -1;
ud.Handle.yparen_box = -ones(1, 2);
ud.Handle.t_box = -1;
ud.Handle.f_box = -1;
ud.Handle.pname_box = -ones(1, ud.nump);
ud.Handle.pvalue_box = -ones(1, ud.nump);
ud.Handle.t0_box = -ones(1, 2);
ud.Handle.y0_box = -ones(1, 2);

% Standard header to set dimensions, etc.

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
%set( 0, 'units', 'pixels' );

x0 = left + 0.01*width;
y0 = bottom + 0.05*height;

buttonheight = 1.7;
menuheight = 2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
eqnboxwidth = 60;

textd = 'd^2 ';
textdwidth = length( textd ) + 2;
textdslash = '/ d';
textdslashwidth = length( textdslash ) + 2;
textequal = ' = ';
textequalwidth = length( textequal ) + 2;

figheight = menuheight ...
    + (varboxheight + vmargin) ...
    + textboxheight ...
    + ceil( ud.nump/2 )*(vmargin + varboxheight) ...
    + vmargin + textboxheight ...
    + 2*(varboxheight + vmargin) ...
    + 2*vmargin + buttonheight + vmargin;
figwidth = hmargin + indent + textdwidth + varboxwidth ...
    + textdslashwidth ...
    + varboxwidth + textequalwidth + eqnboxwidth + vmargin ...
    + indent;

% Open window and build menu bar

h0 = figure('Units','character', ...
    'Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name', 'Second-order equation', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Position',[x0 y0 figwidth figheight], ...
    'Tag','order2');
h1 = uimenu('Parent',h0, ...
    'Label','Equation' );
h2 = uimenu('Parent',h1, ...
    'Label','From list');

    for i = 1:length(defaultlist)
       h3 = uimenu('Parent',h2, ...
           'Callback',[ 'f_order2 FromDefaultList ' num2str(i)  ], ...
           'Label',defaultlist{i}.id);
    end;

h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 Save', ...
    'Label','Save to list',...
    'Enable', 'off' );
h2 = uimenu('Parent',h1, ...
    'Label','Equivalent system',...
    'Callback', 'f_order2 Equiv1stOrder');

h1 = uimenu('Parent',h0, ...
    'Label','Analytic tools', ...
    'Callback', 'f_order2 all_edit; f_order2 all_edit',...
    'Tag','uimenu2');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 AnlSolveODE', ...
    'Label','ODE solution', ...
    'Tag','Analytic tooluimenu1');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 AnlSolveIVP', ...
    'Label','IVP solution', ...
    'Tag','Analytic tooluimenu2');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 StdyState', ...
    'Label','Steady state(s)', ...
    'Tag','Analytic toolsuimenu1');
h1 = uimenu('Parent',h0, ...
    'Label','Numerical tools', ...
    'Tag','uimenu3');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 numivp', ...
    'Label','Approx. solution of IVP', ...
    'Tag','Numerical toolsuimenu1');
h1 = uimenu('Parent',h0, ...
    'Label','Graphical tools', ...
    'Tag','uimenu4');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 phaseplane', ...
    'Label','Phase plane', ...
    'Tag','Graphical toolsuimenu1');
h2 = uimenu('Parent',h1, ...
    'Callback','f_order2 plotvst', ...
    'Label',[ 'Solution plot vs. ' char( ud.t ) ] );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin equation', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

% Equation
x = hmargin + indent;
y = figheight - menuheight;
h1 = uicontrol('Parent',h0, ...
    'Units','character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'ListboxTop',0, ...
    'Position',[ x y textdwidth textboxheight ], ...
    'String',textd, ...
    'Style','text' );

x = x + textdwidth;
y = y - delta;
ud.Handle.y_box = uicontrol('Parent',h0, ...
    'Units','character', ...
    'Callback','f_order2 y_edit', ...
    'BackgroundColor',[1 1 1], ...
    'ListboxTop',0, ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'HorizontalAlignment','center', ...
    'String', char(ud.y),...
    'Style','edit', ...
    'Tag','y_box');

x = x + varboxwidth;
y = y + delta;
h1 = uicontrol('Parent',h0, ...
    'Units','character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'ListboxTop',0, ...
    'Position',[ x y textdslashwidth textboxheight ], ...
    'String',textdslash, ...
    'Style','text', ...
    'Tag','/d_text');

x = x + textdslashwidth;
y = y - delta;
ud.Handle.t_box = uicontrol('Parent',h0, ...
    'Units','character', ...
    'Callback','f_order2 t_edit', ...
    'BackgroundColor',[1 1 1], ...
    'ListboxTop',0, ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'HorizontalAlignment','center', ...
    'String', char(ud.t),...
    'Style','edit', ...
    'Tag','t_box"');

x = x + varboxwidth;
y = y + delta;
h1 = uicontrol('Parent',h0, ...
    'Units','character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'ListboxTop',0, ...
    'Position',[x y textequalwidth textboxheight ], ...
    'String',textequal, ...
    'Style','text', ...
    'Tag','equal_text');

x = x + textequalwidth;
y = y - delta;
ud.Handle.f_box = uicontrol('Parent',h0, ...
    'Units','character', ...
    'Callback','f_order2 f_edit', ...
    'BackgroundColor',[1 1 1], ...
    'ListboxTop',0, ...
    'Position',[ x y eqnboxwidth varboxheight ], ...
    'HorizontalAlignment','left', ...
    'String', char(ud.f),...
    'Style','edit', ...
    'Tag','f_box');

% Parameters
x = hmargin;
y = y - vmargin - delta - textboxheight;

thisboxwidth = 10 + 4;
h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','left', ...
    'ListboxTop',0, ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String','Parameters', ...
    'Style','text' );

if ud.nump == 0
   x = x + thisboxwidth;
   uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','left', ...
    'ListboxTop',0, ...
    'Units', 'character', ...
    'Position',[ x y 7 textboxheight ], ...
    'String',' - none', ...
    'Style','text' );
end  % if

y = y - varboxheight - vmargin;
numpname = length( ud.pname );
for i = 1:2:ud.nump;

   % Parameter boxes on left
   if i > numpname
      name = '';
      value = '';
   else
      name = char(ud.pname{i});
      value = char(ud.pvalue{i});
   end

   x = hmargin + indent;
   ud.Handle.pname_box(i) = uicontrol('Parent',h0, ...
       'Callback','f_order2 pname_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth  varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', name,...
       'Style','edit' );
   x = x + varboxwidth;
   y = y + delta;
   thisboxwidth = 1 + 4;
   h1 = uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'ListboxTop',0, ...
       'Units', 'character', ...
       'Position',[ x y thisboxwidth textboxheight ], ...
       'String','=', ...
       'Style','text' );
   x = x + thisboxwidth;
   y = y - delta;
   ud.Handle.pvalue_box(i) = uicontrol('Parent',h0, ...
       'Callback','f_order2 pvalue_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', value,...
       'Style','edit' );

   % Parameters boxes on right

   if i + 1 > ud.nump
       y = y - varboxheight - vmargin;
       break;
   end

   if i + 1 > numpname
      name = '';
      value = '';
   else
      name = char(ud.pname{i + 1});
      value = char(ud.pvalue{i + 1});
   end

   x = x + varboxwidth + 4*hmargin;
   ud.Handle.pname_box(i + 1) = uicontrol('Parent',h0, ...
       'Callback','f_order2 pname_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth  varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', name,...
       'Style','edit' );
   x = x + varboxwidth;
   y = y + delta;
   thisboxwidth = 1 + 4;
   h1 = uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'ListboxTop',0, ...
       'Units', 'character', ...
       'Position',[ x y thisboxwidth textboxheight ], ...
       'String','=', ...
       'Style','text' );
   x = x + thisboxwidth;
   y = y - delta;
   ud.Handle.pvalue_box(i + 1) = uicontrol('Parent',h0, ...
       'Callback','f_order2 pvalue_edit', ...
       'BackgroundColor',[1 1 1], ...
       'Units', 'character', ...
       'Position',[ x y varboxwidth varboxheight ], ...
       'HorizontalAlignment','center', ...
       'String', value,...
       'Style','edit' );

   y = y - varboxheight - vmargin;
end;

% Initial condition
% y(t0) = y0{1}
x = hmargin;
thisboxwidth = 17 + 4;
h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','left', ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String','Initial condition', ...
    'Style','text' );

y = y - vmargin - varboxheight + delta;
x = hmargin + indent;
thisboxwidth = varboxwidth + 2;
ud.Handle.yparen_box(1) = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','right', ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String', [ char(ud.y) '( ' ], ...
    'Style','text' );

x = x + thisboxwidth;
y = y - delta;
ud.Handle.t0_box(1) = uicontrol('Parent',h0, ...
    'Callback','f_order2 t0_edit', ...
    'BackgroundColor',[1 1 1], ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'HorizontalAlignment','center', ...
    'String', char(ud.t0),...
    'Style','edit' );
x = x + varboxwidth;
y = y + delta;
thisboxwidth = 4 + 1;
h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String',')  =', ...
    'HorizontalAlignment','center', ...
    'Style','text' );

x = x + thisboxwidth;
y = y - delta;
ud.Handle.y0_box(1) = uicontrol('Parent',h0, ...
    'Callback','f_order2 y0_edit', ...
    'BackgroundColor',[1 1 1], ...
    'Units', 'character', ...
    'Position',[ x  y   varboxwidth   varboxheight ], ...
    'HorizontalAlignment','center', ...
    'String', char(ud.y0{1}),...
    'Style','edit' );

% y'(t0) = y0{2}
x = hmargin + indent;
y = y - varboxheight - vmargin;
thisboxwidth = varboxwidth + 2;
ud.Handle.yparen_box(2) = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'HorizontalAlignment','right', ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String', [ char(ud.y) '''(' ], ...
    'Style','text' );

x = x + thisboxwidth;
y = y - delta;
ud.Handle.t0_box(2) = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x (y - delta) varboxwidth varboxheight ], ...
    'HorizontalAlignment','center', ...
    'String', char(ud.t0),...
    'Style','text' );
x = x + varboxwidth;
y = y + delta;
thisboxwidth = 4 + 1;
h1 = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y thisboxwidth textboxheight ], ...
    'String',')  =', ...
    'HorizontalAlignment','center', ...
    'Style','text' );

x = x + thisboxwidth;
y = y - delta;
ud.Handle.y0_box(2) = uicontrol('Parent',h0, ...
    'Callback','f_order2 y0_edit', ...
    'BackgroundColor',[1 1 1], ...
    'Units', 'character', ...
    'Position',[ x  y   varboxwidth   varboxheight ], ...
    'HorizontalAlignment','center', ...
    'String', char(ud.y0{2}),...
    'Style','edit' );

%
%
%
%
%
%    else
%        ud.Handle.t0_box(i) = uicontrol('Parent',h0, ...
%            'BackgroundColor',[0.8 0.8 0.8], ...
%            'Units', 'character', ...
%            'Position',[ x (y - delta) varboxwidth varboxheight ], ...
%            'HorizontalAlignment','center', ...
%            'String', char(ud.t0),...
%            'Style','text' );
%    end   % if
%
%    x = x + varboxwidth;
%    y = y + delta;
%    thisboxwidth = 4 + 1;
%    h1 = uicontrol('Parent',h0, ...
%        'BackgroundColor',[0.8 0.8 0.8], ...
%        'Units', 'character', ...
%        'Position',[ x y thisboxwidth textboxheight ], ...
%        'String',')  =', ...
%        'HorizontalAlignment','center', ...
%        'Style','text' );
%
%    x = x + thisboxwidth;
%    y = y - delta;
%    ud.Handle.y0_box(i) = uicontrol('Parent',h0, ...
%        'Callback','f_order2 y0_edit', ...
%        'BackgroundColor',[1 1 1], ...
%        'Units', 'character', ...
%        'Position',[ x  y   varboxwidth   varboxheight ], ...
%        'HorizontalAlignment','center', ...
%        'String', char(ud.y0{i}),...
%        'Style','edit' );
%
%   y = y - varboxheight - vmargin;
%end   % for

% Buttons at bottom
x = hmargin;
y = vmargin;

buttonstring = 'Add parameter';
buttonwidth = length( buttonstring ) + 4;

uicontrol('Parent',h0, ...
    'Callback','f_order2 AddParameter', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String',buttonstring, ...
    'ToolTipString','Add another parameter' );

x = figwidth - buttonwidth - hmargin;

buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;

h1 = uicontrol('Parent',h0, ...
    'Callback','f_order2 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','close', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

ud.Handle.order2 = h0;
set( h0, 'UserData', ud );

if nargout > 0, fig = h0; end
