function fig = w_phaseline( ud )

% Phase line for scalar 1st order ODEs for DELab

load w_delab
%load w_numcntrl

% Initialize local UserData
pud.tf = ud.tf;
pud.deltat = ud.deltat;
%pud.NumStep = ud.NumStep;
pud.ymin = ud.ymin;
pud.ymax = ud.ymax;
%pud.method = ud.method;
%pud.numpts = 20;
%pud.Handle.NumStep_box = -1;  %dummy for compatibility with NumIVP
pud.targetfig = ' ';
pud.Handle.targetfig = -1;
pud.Handle.order1 = ud.Handle.order1;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

radiobuttonheight = 1.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
radiodelta = (radiobuttonheight - textboxheight)/2;
eqnboxwidth = 50;

hline = '________________________________________';
hlinewidth = 2 + length( hline );

figwidth = 2*indent + 70;
figheight = menuheight + 3.5*(vmargin + varboxheight) + vmargin;

x0 = left  + 0.99*width - figwidth;
y0 = bottom + 0.05*height;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name','Phase line', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin graphical', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

% Display options
x = hmargin + indent;
y = figheight - menuheight;
text = 'Display options';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = hmargin + 2*indent;
y = y - textboxheight - vmargin;
text = 'Plot on';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'new figure';
textwidth = 7 + length( text );
pud.Handle.NewFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 NewFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'figure no.';
textwidth = 5 + length( text );
pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 CurrentFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );
x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.figure_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 targetfig_edit', ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.targetfig ), ...
    'Style','edit' );

%x = x + 2*hmargin + textwidth;
%text = 'previous figure';
%textwidth = 7 + length( text );
%pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
%    'BackgroundColor',[0.8 0.8 0.8], ...
%    'Units', 'character', ...
%    'Callback','f_order1 CurrentFig_radio', ...
%    'Position',[ x y textwidth radiobuttonheight ],...
%    'String',text, ...
%    'Style','radiobutton', ...
%    'Min',0,'Max',1 );
%
x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = [ 'Min ' char( ud.y ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.ymin_box  = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback', 'f_order1 ymin_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( pud.ymin ), ...
    'Style','edit' );

x = x + 2*hmargin + varboxwidth;
y = y + delta;
text = [ 'Max ' char( ud.y ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.ymax_box  = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback', 'f_order1 ymax_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( ud.ymax ), ...
    'Style','edit' );

% Buttons across bottom
x = hmargin + indent;
y = y - 3*vmargin - varboxheight;
buttonstring = 'Start';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 Startphaseline', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Plot', ...
    'ToolTipString','Plot phase line' );

x = figwidth - buttonwidth - hmargin - indent;
buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 closepanel', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

% update "parent" equation window as well
ud.Handle.phaseline = h0;
set( ud.Handle.order1, 'UserData', ud );

if nargout > 0, fig = h0; end
