function fig = w_phasespace( ud )

% Phase space for DELab

load w_delab

% Initialize local UserData
pud.tf = num2str( 10*str2num( ud.tf ) );
pud.deltat = ud.deltat;
pud.NumStep = ud.NumStep;
pud.Handle.NumStep_box = -1;
pud.ymin = ud.ymin;
pud.ymax = ud.ymax;
pud.method = ud.method;
pud.Handle.targetfig = -1;
pud.Handle.order1 = ud.Handle.order1;
pud.numpts = 20;
%pud.Handle.ymin_box = -ones(2, 1);
%pud.Handle.ymax_box = -ones(2, 1);
pud.targetfig = ' ';
pud.Handle.targetfig = -1;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

radiobuttonheight = 1.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
radiodelta = (radiobuttonheight - textboxheight)/2;
eqnboxwidth = 50;

%hline = '________________________________________';
%hlinewidth = 2 + length( hline );

figwidth = 2*indent + 70;

neqn = ud.numeqn;
if neqn > 3, addend = ceil( neqn/3 ); else addend = 0; end
figheight = menuheight + (2.5 + addend)*(vmargin + varboxheight) ...
   + vmargin;
%figheight = menuheight + (2.5 + addend)*(vmargin + varboxheight) + vmargin;

x0 = left  + 0.99*width - figwidth;
y0 = bottom + 0.05*height;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name','Phase space', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );

h1 = uimenu('Parent',h0, ...
    'Label','Options' );
   h2 = uimenu('Parent',h1, ...
       'Label','Solver' );
      % 4 is ode23, 5 is ode45, 6 is ode113, 7 is ode23s, 8 is ode15s
      pud.Handle.ode23 = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 4', ...
          'Label','Runge-Kutta 2/3 (ode23)' );
      pud.Handle.ode45 = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 5', ...
          'Label','Runge-Kutta 4/5 (ode45)' );
      pud.Handle.ode113 = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 6', ...
          'Label','Variable order (ode113)' );
      pud.Handle.ode23s = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 7', ...
          'Label','Low order stiff (ode23s)' );
      pud.Handle.ode15s = uimenu('Parent',h2, ...
          'Callback','f_order1 SetMethod 8', ...
          'Label','Variable order stiff (ode15s)' );
   h2 = uimenu('Parent',h1, ...
       'Label','Direction' );
      pud.Handle.forward = uimenu('Parent',h2, ...
          'Callback','f_order1 SolveForward', ...
          'Label', [ 'Increasing ' char( ud.t ) ] );
      pud.Handle.backward = uimenu('Parent',h2, ...
          'Callback','f_order1 SolveBackward', ...
          'Label', [ 'Decreasing ' char( ud.t ) ] );
      pud.Handle.both = uimenu('Parent',h2, ...
          'Callback','f_order1 SolveForandBack', ...
          'Label', 'Both directions' );
   h2 = uimenu('Parent',h1, ...
       'Callback', 'f_order1 tfdialog',...
       'Label', [ 'Last ' char( ud.t ) ] );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin graphical', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

% Display options
x = hmargin + indent;
y = figheight - menuheight;
text = 'Display options';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = 'Plot on';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'new figure';
textwidth = 7 + length( text );
pud.Handle.NewFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 NewFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'figure no.';
textwidth = 5 + length( text );
pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 CurrentFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );
x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.figure_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 targetfig_edit', ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.targetfig ), ...
    'Style','edit' );

if neqn > 3
   % Variables to show on plot
   x = hmargin + 2*indent;
   y = y - varboxheight - vmargin;
   text = 'Show';
   textwidth = 3 + length( text );
   uicontrol('Parent',h0, ...
       'BackgroundColor',[0.8 0.8 0.8], ...
       'Units', 'character', ...
       'Position',[ x y textwidth textboxheight ], ...
       'HorizontalAlignment','left',...
       'String',text, ...
       'Style','text' );

   xstart = x + 2*hmargin + plottextwidth;
   pud.Handle.showvar = -ones( neqn, 1 );

   textwidth = 0;
   for i = 1:neqn
      textwidth = max( textwidth, length( ud.y{i} ) );
   end  % for
   textwidth = textwidth + 7;

   for i = 1:3:neqn
      x = xstart;
      y = y - radiodelta;
      pud.Handle.showvar(i) = uicontrol('Parent',h0, ...
          'Units', 'character', ...
          'BackgroundColor',[0.8 0.8 0.8], ...
          'Position',[ x y textwidth radiobuttonheight ], ...
          'String', char( ud.y{i} ),...
          'Style','checkbox', ...
          'Min',0,'Max',1 );

      if i + 1 > neqn
          y = y - varboxheight - vmargin;
          break;
      end

      x = x + varboxwidth + hmargin;
      pud.Handle.showvar(i + 1) = uicontrol('Parent',h0, ...
          'Units', 'character', ...
          'BackgroundColor',[0.8 0.8 0.8], ...
          'Position',[ x y textwidth radiobuttonheight ], ...
          'String', char( ud.y{i + 1} ),...
          'Style','checkbox', ...
          'Min',0,'Max',1 );

      if i + 2 > neqn
          y = y - varboxheight - vmargin;
          break;
      end

      x = x + varboxwidth + hmargin;
      pud.Handle.showvar(i + 2) = uicontrol('Parent',h0, ...
          'Units', 'character', ...
          'BackgroundColor',[0.8 0.8 0.8], ...
          'Position',[ x y textwidth radiobuttonheight ], ...
          'String', char( ud.y{i + 2} ),...
          'Style','checkbox', ...
          'Min',0,'Max',1 );
      y = y - varboxheight - vmargin;
   end  % for
end  % if

% Buttons across bottom
x = hmargin + indent;
y = vmargin;
buttonstring = 'Start';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 Startphasespace', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Plot', ...
    'ToolTipString','Plot trajectory in phase space' );

x = figwidth - buttonwidth - hmargin - indent;
buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 closepanel', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

% update "parent" equation window as well
ud.Handle.phasespace = h0;
set( ud.Handle.order1, 'UserData', ud );

if nargout > 0, fig = h0; end
