function fig = w_visdemo( ud )

% Visual demo for fixed-step numerical methods for DELab

load w_delab
%load w_numcntrl

% Initialize local UserData
pud.tf = ud.tf;
pud.deltat = ud.deltat;
pud.NumStep = ud.NumStep;
pud.ymin = ud.ymin;
pud.ymax = ud.ymax;
pud.method = ud.method;
pud.targetfig = ' ';
pud.Handle.targetfig = -1;
pud.Handle.order1 = ud.Handle.order1;

% Establish dimensions.
set( 0, 'units', 'character' );
size = get( 0, 'screensize' );
left = size(1, 1);
bottom = size(1, 2);
width = size(1, 3);
height = size(1, 4);
set( 0, 'units', 'pixels' );

buttonheight = 1.7;
menuheight = 1.2*buttonheight;
hmargin = 2;
indent = 2*hmargin;
vmargin = 0.75;

radiobuttonheight = 1.5;

varboxwidth = 10;  % editable text box for variables
varboxheight = 1.7;
textboxheight = 1;
delta = (varboxheight - textboxheight)/2;
radiodelta = (radiobuttonheight - textboxheight)/2;
eqnboxwidth = 50;

hline = '________________________________________';
hlinewidth = 2 + length( hline );

figwidth = 2*indent + 90;
figheight = menuheight + 9.8*(vmargin + varboxheight) + vmargin;

x0 = left  + 0.99*width - figwidth;
y0 = bottom + 0.05*height;

h0 = figure('Color',[0.8 0.8 0.8], ...
    'Colormap',mat0, ...
    'MenuBar','none', ...
    'Name','Visual demo of numerical approximation of IVP', ...
    'NumberTitle','off', ...
    'PointerShapeCData',mat1, ...
    'Units', 'character', ...
    'Position',[x0 y0 figwidth figheight] );

h1 = uimenu('Parent',h0, ...
    'Label','Options' );
   h2 = uimenu('Parent',h1, ...
       'Label', 'Flow lines' );
%      h3 = uimenu('Parent',h2, ...
%          'Callback', 'f_order1 numpts',...
%          'Label', 'Number' );
      h3 = uimenu('Parent',h2, ...
          'Label', 'Style' );
         pud.Handle.lines = uimenu('Parent',h3, ...
             'Callback', 'f_order1 lines',...
             'Label', 'Lines' );
         pud.Handle.arrows = uimenu('Parent',h3, ...
             'Callback', 'f_order1 arrows',...
             'Label', 'Arrows' );

h1 = uimenu('Parent',h0, ...
    'Label','Help' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin graphical', ...
    'Label','This window' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin contents', ...
    'Label','Contents' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin textbook', ...
    'Label','Textbook' );
   h2 = uimenu('Parent',h1, ...
    'Callback','helpwin about', ...
    'Label','About DELab' );

% Method line
x = hmargin + indent;
y = figheight - menuheight;
text = 'Method:';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );
x = x + hmargin + textwidth;
y = y - delta;
popupwidth = 7 + length( 'Adaptive: variable-order (ode113)' );
popupcell = { 'Euler'; 'Heun/RK2'; 'Runge-Kutta 4';...
   'Adaptive: Runge-Kutta 2/3'; 'Adaptive: Runge-Kutta 4/5';...
   'Adaptive: variable-order (ode113)'; 'Stiff: low-order (ode23s)';
    'Stiff: variable-order (ode15s)' };
callstring = [ 'f_order1 SetMethod get( gcbo, ''Value'' );' ];
pud.Handle.MethodPopUp = uicontrol('Parent',h0, ...
    'BackgroundColor',[ 1 1 1 ], ...
    'Units', 'character', ...
    'Position',[ x y popupwidth varboxheight ], ...
    'Callback', callstring,...
    'String', popupcell, ...
    'Style','popup' );

x = x + popupwidth + 2*hmargin;
y = y + delta;
text = ...
   [ 'Stop at ' char( ud.t ) ' =' ];
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'String',text, ...
    'Style','text' );
x = x + textwidth;
y = y - delta;
pud.Handle.tf_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 tf_edit', ...
    'ListboxTop',0, ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.tf ), ...
    'Style','edit' );

% Step size
string = char( pud.method );
if strcmpi( 'Euler', string ) | strcmpi( 'Heun', string ) ...
   | strcmpi( 'RK4', string )
   visible = 'on';
else
   visible = 'off';
end

x = hmargin + indent;
y = y - varboxheight - vmargin;
text = 'Choose';
textwidth = 2 + length( text );
pud.Handle.Choose_text = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + textwidth;
y = y - radiodelta;
text = 'step size';
textwidth = 7 + length( text );
pud.Handle.StepSize_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 StepSize_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.StepSize_box = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 deltat_edit', ...
    'Position',[ x y varboxwidth varboxheight ],...
    'String',char( pud.deltat ), ...
    'Style','edit' );

x = x + 2*hmargin + textwidth;
y = y + delta - radiodelta;
text = 'number of steps';
textwidth = 7 + length( text );
pud.Handle.NumStep_radio = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Callback','f_order1 NumStep_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.NumStep_box = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 NumStep_edit', ...
    'ListboxTop',0, ...
    'Position',[ x y varboxwidth varboxheight ],...
    'String',char( pud.NumStep ), ...
    'Style','edit' );

x = (figwidth - hlinewidth)/2;
y = y - textboxheight - vmargin;
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y hlinewidth textboxheight ], ...
    'String',hline, ...
    'Style','text' );

% Display options
x = hmargin + indent;
y = y - varboxheight - vmargin;
text = 'Display options';
textwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = hmargin + 2*indent;
y = y - textboxheight - vmargin;
text = 'Plot on';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'new figure';
textwidth = 7 + length( text );
pud.Handle.NewFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 NewFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'figure no.';
textwidth = 5 + length( text );
pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 CurrentFig_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );
x = x + textwidth;
y = y - delta + radiodelta;
pud.Handle.figure_box = uicontrol('Parent',h0, ...
    'BackgroundColor',[1 1 1], ...
    'Callback','f_order1 targetfig_edit', ...
    'Units', 'character', ...
    'Position',[ x y varboxwidth varboxheight ], ...
    'String',char( pud.targetfig ), ...
    'Style','edit' );

%x = x + 2*hmargin + textwidth;
%text = 'previous figure';
%textwidth = 7 + length( text );
%pud.Handle.CurrentFig_radio = uicontrol('Parent',h0, ...
%    'BackgroundColor',[0.8 0.8 0.8], ...
%    'Units', 'character', ...
%    'Callback','f_order1 CurrentFig_radio', ...
%    'Position',[ x y textwidth radiobuttonheight ],...
%    'String',text, ...
%    'Style','radiobutton', ...
%    'Min',0,'Max',1 );
%
%x = 4 + hmargin + 2*indent + plottextwidth;
x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = 'Show high accuracy solution';
textwidth = 7 + length( text );
pud.Handle.high_check = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth radiobuttonheight ], ...
    'String', text,...
    'Style','checkbox', ...
    'Min',0,'Max',1 );

%    'Callback','f_order1 high_check', ...

x = hmargin + 2*indent;
y = y - varboxheight - vmargin;
text = [ 'Min ' char( ud.y ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.ymin_box  = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback', 'f_order1 ymin_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( pud.ymin ), ...
    'Style','edit' );

x = x + 2*hmargin + varboxwidth;
y = y + delta;
text = [ 'Max ' char( ud.y ) ' = ' ];
textwidth = 2 + length( text );
h1 = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Position',[ x y textwidth textboxheight ], ...
    'HorizontalAlignment', 'left', ...
    'String', text,...
    'Style','text' );

x = x + textwidth;
y = y - delta;
pud.Handle.ymax_box  = uicontrol('Parent',h0, ...
    'Units', 'character', ...
    'BackgroundColor',[1 1 1], ...
    'Callback', 'f_order1 ymax_edit', ...
    'Position',[ x y varboxwidth  varboxheight ], ...
    'String',char( ud.ymax ), ...
    'Style','edit' );

x = (figwidth - hlinewidth)/2;
y = y - textboxheight - vmargin;
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y hlinewidth textboxheight ], ...
    'String',hline, ...
    'Style','text' );

%Initial value
x = hmargin + indent;
y = y - varboxheight - vmargin;
text = 'Initial value';
plottextwidth = 2 + length( text );
uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Position',[ x y plottextwidth textboxheight ], ...
    'HorizontalAlignment','left',...
    'String',text, ...
    'Style','text' );

x = x + 2*hmargin + plottextwidth;
y = y - radiodelta;
text = 'Use entered value';
textwidth = 7 + length( text );
pud.Handle.UseEnteredIC_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Callback','f_order1 UseEnteredIC_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

x = x + 2*hmargin + textwidth;
text = 'Click on figure';
textwidth = 7 + length( text );
pud.Handle.ClickIC_radio = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'Visible', visible,...
    'Callback','f_order1 ClickIC_radio', ...
    'Position',[ x y textwidth radiobuttonheight ],...
    'String',text, ...
    'Style','radiobutton', ...
    'Min',0,'Max',1 );

% Buttons across bottom
x = hmargin + indent;
y = y - 3*vmargin - varboxheight;
buttonstring = 'Start';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 Startvisdemo', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Start', ...
    'ToolTipString','Start numerical approximation' );
    %'Execute one step of method' );

x = x + hmargin + buttonwidth;
y = y + delta;
text = 'Now click on figure';
textwidth = length( text ) + 4;
pud.Handle.ClickText = uicontrol('Parent',h0, ...
    'BackgroundColor',[0.8 0.8 0.8], ...
    'Units', 'character', ...
    'ForegroundColor', [ 1 0 0 ], ...
    'HorizontalAlignment', 'left', ...
    'Position',[x  y  textwidth    textboxheight], ...
    'Visible', 'off', ...
    'String',text, ...
    'Style','text' );

%x = x + buttonwidth + hmargin;
%buttonstring = 'All steps';
%buttonwidth = length( buttonstring ) + 4;
%h1 = uicontrol('Parent',h0, ...
%    'Callback','f_order1 ', ...
%    'Units', 'character', ...
%    'Position',[x  y  buttonwidth    buttonheight], ...
%    'String',buttonstring, ...
%    'ToolTipString','Execute all remaining steps' );

x = figwidth - buttonwidth - hmargin - indent;
y = y - delta;
buttonstring = 'Close';
buttonwidth = length( buttonstring ) + 4;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 quit', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Quit', ...
    'ToolTipString','Quit DE Lab' );

x = x - hmargin - buttonwidth;
h1 = uicontrol('Parent',h0, ...
    'Callback','f_order1 closepanel', ...
    'Units', 'character', ...
    'Position',[x  y  buttonwidth    buttonheight], ...
    'String','Close', ...
    'ToolTipString','Close this window' );

set( h0, 'UserData', pud );

% update "parent" equation window as well
ud.Handle.visdemo = h0;
set( ud.Handle.order1, 'UserData', ud );

if nargout > 0, fig = h0; end
